@@ -209,14 +209,11 @@ JXG.extend(
          * @private
          */
         hasPoint: function (x, y) {
-            var prec,
-                type,
+            var prec, type,
                 mp = this.center.coords.usrCoords,
                 p = new Coords(Const.COORDS_BY_SCREEN, [x, y], this.board),
                 r = this.Radius(),
-                dx,
-                dy,
-                dist;
+                dx, dy, dist;
 
             if (Type.isObject(Type.evaluate(this.visProp.precision))) {
                 type = this.board._inputDevice;
@@ -228,9 +225,10 @@ JXG.extend(
             dx = mp[1] - p.usrCoords[1];
             dy = mp[2] - p.usrCoords[2];
             dist = Math.sqrt(dx * dx + dy * dy);
+
             // We have to use usrCoords, since Radius is available in usrCoords only.
             prec += Type.evaluate(this.visProp.strokewidth) * 0.5;
-            prec /= Math.sqrt(this.board.unitX * this.board.unitY);
+            prec /= Math.sqrt(Math.abs(this.board.unitX * this.board.unitY));
 
             if (Type.evaluate(this.visProp.hasinnerpoints)) {
                 return dist < r + prec;
@@ -239,12 +237,12 @@ JXG.extend(
             return Math.abs(dist - r) < prec;
         },
 
-        /**
-         * Used to generate a polynomial for a point p that lies on this circle.
-         * @param {JXG.Point} p The point for which the polynomial is generated.
-         * @returns {Array} An array containing the generated polynomial.
-         * @private
-         */
+        // /**
+        //  * Used to generate a polynomial for a point p that lies on this circle.
+        //  * @param {JXG.Point} p The point for which the polynomial is generated.
+        //  * @returns {Array} An array containing the generated polynomial.
+        //  * @private
+        //  */
         generatePolynomial: function (p) {
             /*
              * We have four methods to construct a circle:
@@ -380,34 +378,10 @@ JXG.extend(
 
                 this.numberPoints = 13;
                 this.dataX = [
-                    x + r,
-                    x + r,
-                    x + r * c,
-                    x,
-                    x - r * c,
-                    x - r,
-                    x - r,
-                    x - r,
-                    x - r * c,
-                    x,
-                    x + r * c,
-                    x + r,
-                    x + r
+                    x + r, x + r, x + r * c, x, x - r * c, x - r, x - r, x - r, x - r * c, x, x + r * c, x + r, x + r
                 ];
                 this.dataY = [
-                    y,
-                    y + r * c,
-                    y + r,
-                    y + r,
-                    y + r,
-                    y + r * c,
-                    y,
-                    y - r * c,
-                    y - r,
-                    y - r,
-                    y - r,
-                    y - r * c,
-                    y
+                    y, y + r * c, y + r, y + r, y + r, y + r * c, y, y - r * c, y - r, y - r, y - r, y - r * c, y
                 ];
                 this.bezierDegree = 3;
                 for (i = 0; i < this.numberPoints; i++) {
@@ -773,6 +747,14 @@ JXG.extend(
             return r * r * Math.PI;
         },
 
+        /**
+         * Perimeter (circumference) of circle.
+         * @returns {Number} Perimeter of circle in user units.
+         */
+        Perimeter: function () {
+            return 2 * this.Radius() * Math.PI;
+        },
+
         /**
          * Get bounding box of the circle.
          * @returns {Array} [x1, y1, x2, y2]
