@@ -237,29 +237,16 @@ JXG.extend(
          * @private
          */
         updateGlider: function () {
-            var i,
-                p1c,
-                p2c,
-                d,
-                v,
-                poly,
-                cc,
-                pos,
-                sgn,
-                alpha,
-                beta,
+            var i, d, v,
+                p1c, p2c, poly, cc, pos,
+                angle, sgn, alpha, beta,
                 delta = 2.0 * Math.PI,
-                angle,
-                cp,
-                c,
-                invMat,
-                newCoords,
-                newPos,
+                cp, c, invMat,
+                newCoords, newPos,
                 doRound = false,
                 ev_sw,
                 slide = this.slideObject,
-                res,
-                cu,
+                res, cu,
                 slides = [],
                 isTransformed;
 
@@ -476,7 +463,7 @@ JXG.extend(
                     // In case, the point is a constrained glider.
                     this.updateConstraint();
 
-                    // Handle the case if the curve comes from a transformation of a continous curve.
+                    // Handle the case if the curve comes from a transformation of a continuous curve.
                     if (slide.transformations.length > 0) {
                         isTransformed = false;
                         res = slide.getTransformationSource();
@@ -552,20 +539,11 @@ JXG.extend(
          * @private
          */
         updateGliderFromParent: function () {
-            var p1c,
-                p2c,
-                r,
-                lbda,
-                c,
+            var p1c, p2c, r, lbda, c,
                 slide = this.slideObject,
                 slides = [],
-                res,
-                i,
-                isTransformed,
-                baseangle,
-                alpha,
-                angle,
-                beta,
+                res, i, isTransformed,
+                baseangle, alpha, angle, beta,
                 delta = 2.0 * Math.PI;
 
             if (!this.needsUpdateFromParent) {
@@ -1193,9 +1171,7 @@ JXG.extend(
         makeGlider: function (slide) {
             var slideobj = this.board.select(slide),
                 onPolygon = false,
-                min,
-                i,
-                dist;
+                min, i, dist;
 
             if (slideobj.type === Const.OBJECT_TYPE_POLYGON) {
                 // Search for the closest edge of the polygon.
@@ -1226,7 +1202,7 @@ JXG.extend(
             this.addParents(slide);
 
             this.type = Const.OBJECT_TYPE_GLIDER;
-            this.elType = "glider";
+            this.elType = 'glider';
             this.visProp.snapwidth = -1; // By default, deactivate snapWidth
             this.slideObject.addChild(this);
             this.isDraggable = true;
@@ -1488,7 +1464,7 @@ JXG.extend(
          * this anchor element.
          * This is handled with this.relativeCoords. If the element is a label
          * relativeCoords are given in scrCoords, otherwise in usrCoords.
-         * @param{Array} coordinates Offset from th anchor element. These are the values for this.relativeCoords.
+         * @param{Array} coordinates Offset from the anchor element. These are the values for this.relativeCoords.
          * In case of a label, coordinates are screen coordinates. Otherwise, coordinates are user coordinates.
          * @param{Boolean} isLabel Yes/no
          * @private
@@ -1560,7 +1536,6 @@ JXG.extend(
             this.isConstrained = true;
 
             this.updateConstraint();
-            //this.coords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
         },
 
         /**
