@@ -883,6 +883,11 @@ JXG.extend(
         /**
          * Show the element or hide it. If hidden, it will still exist but not be
          * visible on the board.
+         * <p>
+         * Sets also the display of the inherits elements. These can be
+         * JSXGraph elements or arrays of JSXGraph elements.
+         * However, deeper nesting than this is not supported.
+         *
          * @param  {Boolean} val true: show the element, false: hide the element
          * @return {JXG.GeometryElement} Reference to the element
          * @private
@@ -911,7 +916,7 @@ JXG.extend(
                         if (
                             Type.exists(obj[i]) &&
                             Type.exists(obj[i].rendNode) &&
-                            Type.evaluate(obj[i].visProp.visible) === "inherit"
+                            Type.evaluate(obj[i].visProp.visible) === 'inherit'
                         ) {
                             obj[i].setDisplayRendNode(val);
                         }
@@ -920,7 +925,7 @@ JXG.extend(
                     if (
                         Type.exists(obj) &&
                         Type.exists(obj.rendNode) &&
-                        Type.evaluate(obj.visProp.visible) === "inherit"
+                        Type.evaluate(obj.visProp.visible) === 'inherit'
                     ) {
                         obj.setDisplayRendNode(val);
                     }
@@ -1058,29 +1063,29 @@ JXG.extend(
         },
 
         /**
-         * Sets the value of property <tt>property</tt> to <tt>value</tt>.
-         * @param {String} property The property's name.
+         * Sets the value of attribute <tt>key</tt> to <tt>value</tt>.
+         * @param {String} key The attribute's name.
          * @param value The new value
          * @private
          */
-        _set: function (property, value) {
+        _set: function (key, value) {
             var el;
 
-            property = property.toLocaleLowerCase();
+            key = key.toLocaleLowerCase();
 
-            // Search for entries in visProp with "color" as part of the property name
+            // Search for entries in visProp with "color" as part of the key name
             // and containing a RGBA string
             if (
-                this.visProp.hasOwnProperty(property) &&
-                property.indexOf("color") >= 0 &&
+                this.visProp.hasOwnProperty(key) &&
+                key.indexOf("color") >= 0 &&
                 Type.isString(value) &&
                 value.length === 9 &&
                 value.charAt(0) === "#"
             ) {
                 value = Color.rgba2rgbo(value);
-                this.visProp[property] = value[0];
+                this.visProp[key] = value[0];
                 // Previously: *=. But then, we can only decrease opacity.
-                this.visProp[property.replace("color", "opacity")] = value[1];
+                this.visProp[key.replace("color", "opacity")] = value[1];
             } else {
                 if (
                     value !== null &&
@@ -1090,14 +1095,14 @@ JXG.extend(
                 ) {
                     // value is of type {prop: val, prop: val,...}
                     // Convert these attributes to lowercase, too
-                    this.visProp[property] = {};
+                    this.visProp[key] = {};
                     for (el in value) {
                         if (value.hasOwnProperty(el)) {
-                            this.visProp[property][el.toLocaleLowerCase()] = value[el];
+                            this.visProp[key][el.toLocaleLowerCase()] = value[el];
                         }
                     }
                 } else {
-                    this.visProp[property] = value;
+                    this.visProp[key] = value;
                 }
             }
         },
@@ -1187,15 +1192,15 @@ JXG.extend(
          * parameters of the following types:
          * <ul>
          * <li> object: {key1:value1,key2:value2,...}
-         * <li> string: "key1:value"
-         * <li> array: [key, value]
+         * <li> string: 'key:value'
+         * <li> array: ['key', value]
          * </ul>
          * @param {Object} attributes An object with attributes.
          * @returns {JXG.GeometryElement} A reference to the element.
          *
          * @function
          * @example
-         * // Set property directly on creation of an element using the attributes object parameter
+         * // Set attribute directly on creation of an element using the attributes object parameter
          * var board = JXG.JSXGraph.initBoard('jxgbox', {boundingbox: [-1, 5, 5, 1]};
          * var p = board.create('point', [2, 2], {visible: false});
          *
@@ -1205,17 +1210,10 @@ JXG.extend(
          *     visible: true
          * });
          */
-        setAttribute: function (attributes) {
-            var i,
-                j,
-                le,
-                key,
-                value,
-                arg,
-                opacity,
-                pair,
-                oldvalue,
-                properties = {};
+        setAttribute: function (attr) {
+            var i, j, le, key, value, arg,
+                opacity, pair, oldvalue,
+                attributes = {};
 
             // Normalize the user input
             for (i = 0; i < arguments.length; i++) {
@@ -1223,23 +1221,23 @@ JXG.extend(
                 if (Type.isString(arg)) {
                     // pairRaw is string of the form 'key:value'
                     pair = arg.split(":");
-                    properties[Type.trim(pair[0])] = Type.trim(pair[1]);
+                    attributes[Type.trim(pair[0])] = Type.trim(pair[1]);
                 } else if (!Type.isArray(arg)) {
                     // pairRaw consists of objects of the form {key1:value1,key2:value2,...}
-                    JXG.extend(properties, arg);
+                    JXG.extend(attributes, arg);
                 } else {
                     // pairRaw consists of array [key,value]
-                    properties[arg[0]] = arg[1];
+                    attributes[arg[0]] = arg[1];
                 }
             }
 
             // Handle shortcuts
-            properties = this.resolveShortcuts(properties);
+            attributes = this.resolveShortcuts(attributes);
 
-            for (i in properties) {
-                if (properties.hasOwnProperty(i)) {
+            for (i in attributes) {
+                if (attributes.hasOwnProperty(i)) {
                     key = i.replace(/\s+/g, "").toLowerCase();
-                    value = properties[i];
+                    value = attributes[i];
 
                     // This handles the subobjects, if the key:value pairs are contained in an object.
                     // Example:
@@ -1400,11 +1398,11 @@ JXG.extend(
                                 this.addRotation(value);
                             }
                             break;
-                        case "ticksdistance":
-                            if (this.type === Const.OBJECT_TYPE_TICKS && Type.isNumber(value)) {
-                                this.ticksFunction = this.makeTicksFunction(value);
-                            }
-                            break;
+                        // case "ticksdistance":
+                        //     if (this.type === Const.OBJECT_TYPE_TICKS && Type.isNumber(value)) {
+                        //         this.ticksFunction = this.makeTicksFunction(value);
+                        //     }
+                        //     break;
                         case "generatelabelvalue":
                             if (
                                 this.type === Const.OBJECT_TYPE_TICKS &&
@@ -1467,7 +1465,7 @@ JXG.extend(
                 }
             }
 
-            this.triggerEventHandlers(["attribute"], [properties, this]);
+            this.triggerEventHandlers(["attribute"], [attributes, this]);
 
             if (!Type.evaluate(this.visProp.needsregularupdate)) {
                 this.board.fullUpdate();
@@ -1768,7 +1766,7 @@ JXG.extend(
         },
 
         /**
-         * Rotate texts or images by a given degree. Works only for texts where JXG.Text#display equal to "internal".
+         * Rotate texts or images by a given degree.
          * @param {number} angle The degree of the rotation (90 means vertical text).
          * @see JXG.GeometryElement#rotate
          */
@@ -1781,8 +1779,7 @@ JXG.extend(
                 that = this;
 
             if (
-                ((this.elementClass === Const.OBJECT_CLASS_TEXT &&
-                    Type.evaluate(this.visProp.display) === "internal") ||
+                (this.elementClass === Const.OBJECT_CLASS_TEXT ||
                     this.type === Const.OBJECT_TYPE_IMAGE) &&
                 angle !== 0
             ) {
@@ -2181,17 +2178,17 @@ JXG.extend(
                         if (!fromParent) {
                             mi = Math.min(boardBB[0], boardBB[2]);
                             ma = Math.max(boardBB[0], boardBB[2]);
-                            if (x < mi) {
+                            if (x < mi && x > mi - sX) {
                                 x += sX;
-                            } else if (x > ma) {
+                            } else if (x > ma && x < ma + sX) {
                                 x -= sX;
                             }
 
                             mi = Math.min(boardBB[1], boardBB[3]);
                             ma = Math.max(boardBB[1], boardBB[3]);
-                            if (y < mi) {
+                            if (y < mi && y > mi - sY) {
                                 y += sY;
-                            } else if (y > ma) {
+                            } else if (y > ma && y < ma + sY) {
                                 y -= sY;
                             }
                         }
@@ -2263,6 +2260,112 @@ JXG.extend(
          */
         removeEvent: JXG.shortcut(JXG.GeometryElement.prototype, 'off'),
 
+        /**
+         * Format a number according to the locale set in the attribute "intl".
+         * If in the options of the intl-attribute "maximumFractionDigits" is not set, 
+         * the optional parameter digits is used instead.
+         * See <a href="https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat">https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat/NumberFormat</a>
+         * for more  information about internationalization.
+         * 
+         * @param {Number} value Number to be formatted
+         * @param {Number} [digits=undefined] Optional number of digits
+         * @returns {String|Number} string containing the formatted number according to the locale 
+         * or the number itself of the formatting is not possible.
+         */
+        formatNumberLocale: function(value, digits) {
+            var loc, opt, key,
+                optCalc = {},
+                // These options are case sensitive:
+                translate = {
+                    maximumfractiondigits: 'maximumFractionDigits',
+                    minimumfractiondigits: 'minimumFractionDigits',
+                    compactdisplay: 'compactDisplay',
+                    currencydisplay: 'currencyDisplay',
+                    currencysign: 'currencySign',
+                    localematcher: 'localeMatcher',
+                    numberingsystem: 'numberingSystem',
+                    signdisplay: 'signDisplay',
+                    unitdisplay: 'unitDisplay',
+                    usegrouping: 'useGrouping',
+                    roundingmode: 'roundingMode',
+                    roundingpriority: 'roundingPriority',
+                    roundingincrement: 'roundingIncrement',
+                    trailingzerodisplay: 'trailingZeroDisplay',
+                    minimumintegerdigits: 'minimumIntegerDigits',
+                    minimumsignificantdigits: 'minimumSignificantDigits',
+                    maximumsignificantdigits: 'maximumSignificantDigits',
+                };
+
+            if (Type.exists(Intl) &&
+                this.useLocale())  {
+
+                loc = Type.evaluate(this.visProp.intl.locale) ||
+                        Type.evaluate(this.board.attr.intl.locale);
+                opt = Type.evaluate(this.visProp.intl.options) || {};
+
+                // Transfer back to camel case if necessary
+                // and evaluate
+                for (key in opt) {
+                    if (opt.hasOwnProperty(key)) {
+                        if (translate.hasOwnProperty(key)) {
+                            optCalc[translate[key]] = Type.evaluate(opt[key]);
+                        } else {
+                            optCalc[key] = Type.evaluate(opt[key]);
+                        }
+                    }
+                }
+
+                // If maximumfractiondigits is not set,
+                // the value of the attribute "digits" is taken instead.
+                key = 'maximumfractiondigits';
+                if (!Type.exists(opt[key])) {
+                    optCalc[translate[key]] = digits;
+
+                    // key = 'minimumfractiondigits';
+                    // if (!Type.exists(opt[key]) || Type.evaluate(opt[key]) > digits) {
+                    //     optCalc[translate[key]] = digits;
+                    // }
+                }
+
+                return Intl.NumberFormat(loc, optCalc).format(value);
+            }
+
+            return value;
+        },
+
+        /**
+         * Checks if locale is enabled in the attribute. This may be in the attributes of the board,
+         * or in the attributes of the text. The latter has higher priority. The board attribute is taken if 
+         * attribute "intl.enabled" of the text element is set to 'inherit'.
+         * 
+         * @returns {Boolean} if locale can be used for number formatting.
+         */
+        useLocale: function() {
+            var val;
+
+            // Check if element supports intl
+            if (!Type.exists(this.visProp.intl) ||
+                !Type.exists(this.visProp.intl.enabled)) {
+                return false;
+            }
+
+            // Check if intl is supported explicitly enabled for this element
+            val = Type.evaluate(this.visProp.intl.enabled);
+
+            if (val === true) {
+                return true;
+            }
+
+            // Check intl attribute of the board
+            if (val === 'inherit') {
+                if (Type.evaluate(this.board.attr.intl.enabled) === true) {
+                    return true;
+                }
+            }
+
+            return false;
+        },
+
         /* **************************
          *     EVENT DEFINITION
          * for documentation purposes
@@ -2351,7 +2454,7 @@ JXG.extend(
 
         /**
          * @event
-         * @description This event is fired whenever the user drags the element by pressing arrow keys 
+         * @description This event is fired whenever the user drags the element by pressing arrow keys
          * on the keyboard.
          * @name JXG.GeometryElement#keydrag
          * @param {Event} e The browser's event object.
