@@ -138,6 +138,7 @@ JXG.Line = function (board, p1, p2, attributes) {
         getRise: "getRise",
         getYIntersect: "getRise",
         getAngle: "getAngle",
+        Slope: "Slope",
         L: "L",
         length: "L"
     });
@@ -157,16 +158,8 @@ JXG.extend(
         hasPoint: function (x, y) {
             // Compute the stdform of the line in screen coordinates.
             var c = [],
-                s,
                 v = [1, x, y],
-                vnew,
-                p1c,
-                p2c,
-                d,
-                pos,
-                i,
-                prec,
-                type,
+                s, vnew, p1c, p2c, d, pos, i, prec, type,
                 sw = Type.evaluate(this.visProp.strokewidth);
 
             if (Type.isObject(Type.evaluate(this.visProp.precision))) {
@@ -475,14 +468,14 @@ JXG.extend(
             return this;
         },
 
-        /**
-         * Used to generate a polynomial for a point p that lies on this line, i.e. p is collinear to
-         * {@link JXG.Line#point1} and {@link JXG.Line#point2}.
-         *
-         * @param {JXG.Point} p The point for that the polynomial is generated.
-         * @returns {Array} An array containing the generated polynomial.
-         * @private
-         */
+        // /**
+        //  * Used to generate a polynomial for a point p that lies on this line, i.e. p is collinear to
+        //  * {@link JXG.Line#point1} and {@link JXG.Line#point2}.
+        //  *
+        //  * @param {JXG.Point} p The point for that the polynomial is generated.
+        //  * @returns {Array} An array containing the generated polynomial.
+        //  * @private
+        //  */
         generatePolynomial: function (p) {
             var u1 = this.point1.symbolic.x,
                 u2 = this.point1.symbolic.y,
@@ -510,31 +503,7 @@ JXG.extend(
 
             return [
                 [
-                    "(",
-                    u2,
-                    ")*(",
-                    w1,
-                    ")-(",
-                    u2,
-                    ")*(",
-                    v1,
-                    ")+(",
-                    w2,
-                    ")*(",
-                    v1,
-                    ")-(",
-                    u1,
-                    ")*(",
-                    w2,
-                    ")+(",
-                    u1,
-                    ")*(",
-                    v2,
-                    ")-(",
-                    w1,
-                    ")*(",
-                    v2,
-                    ")"
+                    "(", u2, ")*(", w1, ")-(", u2, ")*(", v1, ")+(", w2, ")*(", v1, ")-(", u1, ")*(", w2, ")+(", u1, ")*(", v2, ")-(", w1, ")*(", v2, ")"
                 ].join("")
             ];
         },
@@ -555,7 +524,7 @@ JXG.extend(
          * Calculates the slope of the line.
          * @returns {Number} The slope of the line or Infinity if the line is parallel to the y-axis.
          */
-        getSlope: function () {
+        Slope: function () {
             if (Math.abs(this.stdform[2]) >= Mat.eps) {
                 return -this.stdform[1] / this.stdform[2];
             }
@@ -563,6 +532,16 @@ JXG.extend(
             return Infinity;
         },
 
+        /**
+         * Alias for line.Slope
+         * @returns {Number} The slope of the line or Infinity if the line is parallel to the y-axis.
+         * @deprecated
+         * @see #Slope
+         */
+        getSlope: function () {
+            return this.Slope();
+        },
+
         /**
          * Determines the angle between the positive x axis and the line.
          * @returns {Number}
@@ -618,8 +597,7 @@ JXG.extend(
 
         // documented in geometry element
         getLabelAnchor: function () {
-            var x,
-                y,
+            var x, y,
                 fs = 0,
                 c1 = new Coords(Const.COORDS_BY_USER, this.point1.coords.usrCoords, this.board),
                 c2 = new Coords(Const.COORDS_BY_USER, this.point2.coords.usrCoords, this.board),
@@ -638,6 +616,14 @@ JXG.extend(
             }
 
             switch (Type.evaluate(this.label.visProp.position)) {
+                case 'last':
+                    x = c2[1];
+                    y = c2[2];
+                    break
+                case 'first':
+                    x = c1[1];
+                    y = c1[2];
+                    break
                 case "lft":
                 case "llft":
                 case "ulft":
@@ -1062,12 +1048,7 @@ JXG.extend(
  * </script><pre>
  */
 JXG.createLine = function (board, parents, attributes) {
-    var ps,
-        el,
-        p1,
-        p2,
-        i,
-        attr,
+    var ps, el, p1, p2, i, attr,
         c = [],
         doTransform = false,
         constrained = false,
@@ -1078,9 +1059,8 @@ JXG.createLine = function (board, parents, attributes) {
      * In the latter case, the points are created.
      */
     if (parents.length === 2) {
-        // point 1 given by coordinates
+        attr = Type.copyAttributes(attributes, board.options, "line", "point1");
         if (Type.isArray(parents[0]) && parents[0].length > 1) {
-            attr = Type.copyAttributes(attributes, board.options, "line", "point1");
             p1 = board.create("point", parents[0], attr);
         } else if (Type.isString(parents[0]) || Type.isPoint(parents[0])) {
             p1 = board.select(parents[0]);
@@ -1092,12 +1072,10 @@ JXG.createLine = function (board, parents, attributes) {
             parents[0]().length &&
             parents[0]().length >= 2
         ) {
-            attr = Type.copyAttributes(attributes, board.options, "line", "point1");
             p1 = JXG.createPoint(board, parents[0](), attr);
             constrained = true;
         } else if (Type.isObject(parents[0]) && Type.isTransformationOrArray(parents[1])) {
             doTransform = true;
-            attr = Type.copyAttributes(attributes, board.options, "line", "point1");
             p1 = board.create("point", [parents[0].point1, parents[1]], attr);
         } else {
             throw new Error(
@@ -1111,11 +1089,10 @@ JXG.createLine = function (board, parents, attributes) {
         }
 
         // point 2 given by coordinates
+        attr = Type.copyAttributes(attributes, board.options, "line", "point2");
         if (doTransform) {
-            attr = Type.copyAttributes(attributes, board.options, "line", "point2");
             p2 = board.create("point", [parents[0].point2, parents[1]], attr);
         } else if (Type.isArray(parents[1]) && parents[1].length > 1) {
-            attr = Type.copyAttributes(attributes, board.options, "line", "point2");
             p2 = board.create("point", parents[1], attr);
         } else if (Type.isString(parents[1]) || Type.isPoint(parents[1])) {
             p2 = board.select(parents[1]);
@@ -1127,7 +1104,6 @@ JXG.createLine = function (board, parents, attributes) {
             parents[1]().length &&
             parents[1]().length >= 2
         ) {
-            attr = Type.copyAttributes(attributes, board.options, "line", "point2");
             p2 = JXG.createPoint(board, parents[1](), attr);
             constrained = true;
         } else {
@@ -1142,7 +1118,6 @@ JXG.createLine = function (board, parents, attributes) {
         }
 
         attr = Type.copyAttributes(attributes, board.options, "line");
-
         el = new JXG.Line(board, p1, p2, attr);
 
         if (constrained) {
@@ -1184,22 +1159,16 @@ JXG.createLine = function (board, parents, attributes) {
             }
         }
 
-        // point 1 is the midpoint between (0,c,-b) and point 2. => point1 is finite.
+        // point 1 is the midpoint between (0, c, -b) and point 2. => point1 is finite.
         attr = Type.copyAttributes(attributes, board.options, "line", "point1");
         if (isDraggable) {
-            p1 = board.create(
-                "point",
-                [
+            p1 = board.create("point", [
                     c[2]() * c[2]() + c[1]() * c[1](),
                     c[2]() - c[1]() * c[0]() + c[2](),
                     -c[1]() - c[2]() * c[0]() - c[1]()
-                ],
-                attr
-            );
+                ], attr);
         } else {
-            p1 = board.create(
-                "point",
-                [
+            p1 = board.create("point", [
                     function () {
                         return (c[2]() * c[2]() + c[1]() * c[1]()) * 0.5;
                     },
@@ -1209,27 +1178,19 @@ JXG.createLine = function (board, parents, attributes) {
                     function () {
                         return (-c[1]() - c[2]() * c[0]() - c[1]()) * 0.5;
                     }
-                ],
-                attr
-            );
+                ], attr);
         }
 
         // point 2: (b^2+c^2,-ba+c,-ca-b)
         attr = Type.copyAttributes(attributes, board.options, "line", "point2");
         if (isDraggable) {
-            p2 = board.create(
-                "point",
-                [
+            p2 = board.create("point", [
                     c[2]() * c[2]() + c[1]() * c[1](),
                     -c[1]() * c[0]() + c[2](),
                     -c[2]() * c[0]() - c[1]()
-                ],
-                attr
-            );
+                ], attr);
         } else {
-            p2 = board.create(
-                "point",
-                [
+            p2 = board.create("point", [
                     function () {
                         return c[2]() * c[2]() + c[1]() * c[1]();
                     },
@@ -1239,9 +1200,7 @@ JXG.createLine = function (board, parents, attributes) {
                     function () {
                         return -c[2]() * c[0]() - c[1]();
                     }
-                ],
-                attr
-            );
+                ], attr);
         }
 
         // If the line will have a glider and board.suspendUpdate() has been called, we
@@ -1279,9 +1238,7 @@ JXG.createLine = function (board, parents, attributes) {
         ps = parents[0];
 
         attr = Type.copyAttributes(attributes, board.options, "line", "point1");
-        p1 = board.create(
-            "point",
-            [
+        p1 = board.create("point", [
                 function () {
                     var c = ps();
 
@@ -1291,14 +1248,10 @@ JXG.createLine = function (board, parents, attributes) {
                         (-c[1] - c[2] * c[0] - c[1]) * 0.5
                     ];
                 }
-            ],
-            attr
-        );
+            ], attr);
 
         attr = Type.copyAttributes(attributes, board.options, "line", "point2");
-        p2 = board.create(
-            "point",
-            [
+        p2 = board.create("point", [
                 function () {
                     var c = ps();
 
@@ -1308,9 +1261,7 @@ JXG.createLine = function (board, parents, attributes) {
                         -c[2] * c[0] - c[1]
                     ];
                 }
-            ],
-            attr
-        );
+            ], attr);
 
         attr = Type.copyAttributes(attributes, board.options, "line");
         el = new JXG.Line(board, p1, p2, attr);
@@ -1596,7 +1547,7 @@ JXG.registerElement("axis", JXG.createAxis);
  * </script><pre>
  */
 JXG.createTangent = function (board, parents, attributes) {
-    var p, c, j, el, tangent;
+    var p, c, j, el, tangent, attr;
 
     // One argument: glider on line, circle or curve
     if (parents.length === 1) {
@@ -1632,8 +1583,9 @@ JXG.createTangent = function (board, parents, attributes) {
         );
     }
 
+    attr = Type.copyAttributes(attributes, board.options, 'tangent');
     if (c.elementClass === Const.OBJECT_CLASS_LINE) {
-        tangent = board.create("line", [c.point1, c.point2], attributes);
+        tangent = board.create("line", [c.point1, c.point2], attr);
         tangent.glider = p;
     } else if (
         c.elementClass === Const.OBJECT_CLASS_CURVE &&
@@ -1658,7 +1610,7 @@ JXG.createTangent = function (board, parents, attributes) {
                         return -Numerics.D(c.X)(p.position);
                     }
                 ],
-                attributes
+                attr
             );
 
             p.addChild(tangent);
@@ -1681,16 +1633,7 @@ JXG.createTangent = function (board, parents, attributes) {
                 [
                     function () {
                         var i = Math.floor(p.position),
-                            p1,
-                            p2,
-                            t,
-                            A,
-                            B,
-                            C,
-                            D,
-                            dx,
-                            dy,
-                            d;
+                            p1, p2, t, A, B, C, D, dx, dy, d;
 
                         if (c.bezierDegree === 1) {
                             if (i === c.numberPoints - 1) {
@@ -1741,16 +1684,7 @@ JXG.createTangent = function (board, parents, attributes) {
                     },
                     function () {
                         var i = Math.floor(p.position),
-                            p1,
-                            p2,
-                            t,
-                            A,
-                            B,
-                            C,
-                            D,
-                            dx,
-                            dy,
-                            d;
+                            p1, p2, t, A, B, C, D, dx, dy, d;
 
                         if (c.bezierDegree === 1) {
                             if (i === c.numberPoints - 1) {
@@ -1801,16 +1735,7 @@ JXG.createTangent = function (board, parents, attributes) {
                     },
                     function () {
                         var i = Math.floor(p.position),
-                            p1,
-                            p2,
-                            t,
-                            A,
-                            B,
-                            C,
-                            D,
-                            dx,
-                            dy,
-                            d;
+                            p1, p2, t, A, B, C, D, dx, dy, d;
 
                         if (c.bezierDegree === 1) {
                             if (i === c.numberPoints - 1) {
@@ -1860,7 +1785,7 @@ JXG.createTangent = function (board, parents, attributes) {
                         return p1[1] - p2[1];
                     }
                 ],
-                attributes
+                attr
             );
 
             p.addChild(tangent);
@@ -1946,7 +1871,7 @@ JXG.createTangent = function (board, parents, attributes) {
                     return el.X(i) - el.X(i + 1);
                 }
             ],
-            attributes
+            attr
         );
         p.addChild(tangent);
 
@@ -1971,7 +1896,7 @@ JXG.createTangent = function (board, parents, attributes) {
                     return Mat.matVecMult(c.quadraticform, p.coords.usrCoords)[2];
                 }
             ],
-            attributes
+            attr
         );
 
         p.addChild(tangent);
