@@ -109,7 +109,7 @@ JXG.extend(
             }
             r = parseFloat(Type.evaluate(this.visProp.size));
             if (unit === "user") {
-                r *= Math.sqrt(this.board.unitX * this.board.unitY);
+                r *= Math.sqrt(Math.abs(this.board.unitX * this.board.unitY));
             }
 
             r += parseFloat(Type.evaluate(this.visProp.strokewidth)) * 0.5;
@@ -202,7 +202,7 @@ JXG.extend(
                 el2,
                 i,
                 j,
-                Type.evaluate(this.visProp.alwaysintersect)
+                this.visProp.alwaysintersect
             );
             this.addConstraint([func]);
 
@@ -461,6 +461,7 @@ JXG.extend(
  * and the property fixed is not set or set to false. If one or more parent elements is not a number but a string containing a GEONE<sub>x</sub>T
  * constraint or a function the point will be considered as constrained). That means that the user won't be able to change the point's
  * position directly.
+ * @see Glider for a non-free point that is attached to another geometric element.
  * @pseudo
  * @description
  * @name Point
@@ -608,7 +609,7 @@ JXG.createGlider = function (board, parents, attributes) {
  * @constructor
  * @type JXG.Point
  * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
- * @param {JXG.Line,JXG.Circle_JXG.Line,JXG.Circle_Number} el1,el2,i The result will be a intersection point on el1 and el2. i determines the
+ * @param {JXG.Line,JXG.Circle_JXG.Line,JXG.Circle_Number|Function} el1,el2,i The result will be a intersection point on el1 and el2. i determines the
  * intersection point if two points are available: <ul>
  *   <li>i==0: use the positive square root,</li>
  *   <li>i==1: use the negative square root.</li></ul>
