@@ -44,23 +44,18 @@ import GeometryElement from "./element";
  * Creates a new instance of JXG.Polygon.
  * @class Polygon stores all style and functional properties that are required
  * to draw and to interactact with a polygon.
+ * @constructor
+ * @augments JXG.GeometryElement
  * @param {JXG.Board} board Reference to the board the polygon is to be drawn on.
  * @param {Array} vertices Unique identifiers for the points defining the polygon.
  * Last point must be first point. Otherwise, the first point will be added at the list.
  * @param {Object} attributes An object which contains properties as given in {@link JXG.Options.elements}
  * and {@link JXG.Options.polygon}.
- * @constructor
- * @extends JXG.GeometryElement
  */
-
 JXG.Polygon = function (board, vertices, attributes) {
     this.constructor(board, attributes, Const.OBJECT_TYPE_POLYGON, Const.OBJECT_CLASS_AREA);
 
-    var i,
-        l,
-        len,
-        j,
-        p,
+    var i, l, len, j, p,
         attr_line = Type.copyAttributes(attributes, board.options, "polygon", "borders");
 
     this.withLines = attributes.withlines;
@@ -120,6 +115,7 @@ JXG.Polygon = function (board, vertices, attributes) {
             l.dump = false;
             this.borders[i] = l;
             l.parentPolygon = this;
+            this.addChild(l);
         }
     }
 
@@ -247,16 +243,14 @@ JXG.extend(
          * Uses the boards renderer to update the polygon.
          */
         updateRenderer: function () {
-            var i, len; // wasReal,
+            var i, len;
 
             if (!this.needsUpdate) {
                 return this;
             }
 
             if (this.visPropCalc.visible) {
-                // wasReal = this.isReal;
-
-                len = this.vertices.length;
+                len = this.vertices.length - ((this.elType === "polygonalchain") ? 0 : 1);
                 this.isReal = true;
                 for (i = 0; i < len; ++i) {
                     if (!this.vertices[i].isReal) {
@@ -265,11 +259,16 @@ JXG.extend(
                     }
                 }
 
-                if (
-                    //wasReal &&
-                    !this.isReal
-                ) {
+                if (!this.isReal) {
                     this.updateVisibility(false);
+
+                    for (i in this.childElements) {
+                        if (this.childElements.hasOwnProperty(i)) {
+                            // All child elements are hidden.
+                            // This may be weakened to all borders and only vertices with with visible:'inherit'
+                            this.childElements[i].setDisplayRendNode(false);
+                        }
+                    }
                 }
             }
 
@@ -278,8 +277,7 @@ JXG.extend(
             }
 
             /* Update the label if visible. */
-            if (
-                this.hasLabel &&
+            if (this.hasLabel &&
                 this.visPropCalc.visible &&
                 this.label &&
                 this.label.visPropCalc.visible &&
@@ -291,14 +289,6 @@ JXG.extend(
 
             // Update rendNode display
             this.setDisplayRendNode();
-            // if (this.visPropCalc.visible !== this.visPropOld.visible) {
-            //     this.board.renderer.display(this, this.visPropCalc.visible);
-            //     this.visPropOld.visible = this.visPropCalc.visible;
-            //
-            //     if (this.hasLabel) {
-            //         this.board.renderer.display(this.label, this.label.visPropCalc.visible);
-            //     }
-            // }
 
             this.needsUpdate = false;
             return this;
@@ -431,8 +421,10 @@ JXG.extend(
         },
 
         /**
-         * Perimeter of polygon.
+         * Perimeter of polygon. For a polygonal chain, this method returns its length.
+         *
          * @returns {Number} Perimeter of polygon in user units.
+         * @see JXG.Polygon#L
          *
          * @example
          * var p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [1.0, 3.0]];
@@ -462,6 +454,16 @@ JXG.extend(
             return val;
         },
 
+        /**
+         * Alias for Perimeter. For polygons, the perimeter is returned. For polygonal chains the length is returned.
+         *
+         * @returns Number
+         * @see JXG.Polygon#Perimeter
+         */
+        L: function() {
+            return this.Perimeter();
+        },
+
         /**
          * Bounding box of a polygon. The bounding box is an array of four numbers: the first two numbers
          * determine the upper left corner, the last two number determine the lower right corner of the bounding box.
@@ -559,7 +561,6 @@ JXG.extend(
          * @param {JXG.Point} p Arbitrary number of points or coordinate arrays
          * @returns {JXG.Polygon} Reference to the polygon
          * @example
-         * const board = JXG.JSXGraph.initBoard('jxgbox', {axis:true});
          * var pg = board.create('polygon', [[1,2], [3,4], [-3,1]], {hasInnerPoints: true});
          * var newPoint = board.create('point', [-1, -1]);
          * var newPoint2 = board.create('point', [-1, -2]);
@@ -570,7 +571,6 @@ JXG.extend(
          *     (function() {
          *         var board = JXG.JSXGraph.initBoard('JXG70eb0fd2-d20f-4ba9-9ab6-0eac92aabfa5',
          *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
-         *     const board = JXG.JSXGraph.initBoard('jxgbox', {axis:true});
          *     var pg = board.create('polygon', [[1,2], [3,4], [-3,1]], {hasInnerPoints: true});
          *     var newPoint = board.create('point', [-1, -1]);
          *     var newPoint2 = board.create('point', [-1, -2]);
@@ -594,7 +594,7 @@ JXG.extend(
         },
 
         /**
-         * Insert points to the vertex list of the polygon after index <tt><idx</tt>.
+         * Insert points to the vertex list of the polygon after index <tt>idx</tt>.
          * The attributes of new border segments are set to the same values
          * as those used when the polygon was created.
          * If new vertices are supplied by coordinates, the default attributes of polygon
@@ -607,7 +607,6 @@ JXG.extend(
          * @returns {JXG.Polygon} Reference to the polygon object
          *
          * @example
-         * const board = JXG.JSXGraph.initBoard('jxgbox', {axis:true});
          * var pg = board.create('polygon', [[1,2], [3,4], [-3,1]], {hasInnerPoints: true});
          * var newPoint = board.create('point', [-1, -1]);
          * pg.insertPoints(0, newPoint, newPoint, [1, -2]);
@@ -617,7 +616,6 @@ JXG.extend(
          *     (function() {
          *         var board = JXG.JSXGraph.initBoard('JXG17b84b2a-a851-4e3f-824f-7f6a60f166ca',
          *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
-         *     const board = JXG.JSXGraph.initBoard('jxgbox', {axis:true});
          *     var pg = board.create('polygon', [[1,2], [3,4], [-3,1]], {hasInnerPoints: true});
          *     var newPoint = board.create('point', [-1, -1]);
          *     pg.insertPoints(0, newPoint, newPoint, [1, -2]);
@@ -850,7 +848,7 @@ JXG.extend(
                     this.borders.push(
                         this.board.create(
                             "segment",
-                            [this.vertices[0], this.vertices[this.vertices.length - 2]],
+                            [this.vertices[this.vertices.length - 2], this.vertices[0]],
                             this.attr_line
                         )
                     );
@@ -1135,7 +1133,7 @@ JXG.extend(
  * @pseudo
  * @constructor
  * @name Polygon
- * @type Polygon
+ * @type JXG.Polygon
  * @augments JXG.Polygon
  * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
  * @param {Array} vertices The polygon's vertices. If the first and the last vertex don't match the first one will be
@@ -1223,10 +1221,7 @@ JXG.extend(
  *
  */
 JXG.createPolygon = function (board, parents, attributes) {
-    var el,
-        i,
-        le,
-        obj,
+    var el, i, le, obj,
         points = [],
         attr,
         attr_points,
@@ -1342,12 +1337,9 @@ JXG.createPolygon = function (board, parents, attributes) {
  *
  */
 JXG.createRegularPolygon = function (board, parents, attributes) {
-    var el,
-        i,
-        n,
+    var el, i, n,
         p = [],
-        rot,
-        len,
+        rot, len,
         pointsExist,
         attr;
 
@@ -1428,7 +1420,7 @@ JXG.createRegularPolygon = function (board, parents, attributes) {
  * @param {Array} vertices The polygon's vertices.
  *
  * Additionally, a polygonal chain can be created by providing a polygonal chain and a transformation (or an array of transformations).
- * The result is a polygonal chain which is the transformation of the supplied polygona chain.
+ * The result is a polygonal chain which is the transformation of the supplied polygonal chain.
  *
  * @example
  *     var attr = {
