@@ -71,6 +71,8 @@ var priv = {
  *
  */
 JXG.Text = function (board, coords, attributes, content) {
+    var tmp;
+
     this.constructor(board, attributes, Const.OBJECT_TYPE_TEXT, Const.OBJECT_CLASS_TEXT);
 
     this.element = this.board.select(attributes.anchor);
@@ -101,7 +103,13 @@ JXG.Text = function (board, coords, attributes, content) {
     // this._createFctUpdateText(content);
     // this.updateText();
 
+    // Set attribute visible to true. This is necessary to
+    // create all sub-elements for button, input and checkbox
+    tmp = this.visProp.visible;
+    this.visProp.visible = true;
     this.setText(content);
+    // Restore the correct attribute visible.
+    this.visProp.visible = tmp;
 
     if (Type.isString(this.content)) {
         this.notifyParents(this.content);
@@ -111,7 +119,7 @@ JXG.Text = function (board, coords, attributes, content) {
     this.methodMap = Type.deepCopy(this.methodMap, {
         setText: "setTextJessieCode",
         // free: 'free',
-        move: "setCoords"
+        // move: "setCoords"
     });
 };
 
@@ -186,13 +194,15 @@ JXG.extend(
 
         /**
          * This sets the updateText function of this element depending on the type of text content passed.
-         * Used by {@link JXG.Text#_setText} and {@link JXG.Text} constructor.
+         * Used by {@link JXG.Text#_setText}.
          * @param {String|Function|Number} text
          * @private
+         * @see JXG.Text#_setText
          */
         _createFctUpdateText: function (text) {
-            var updateText, e,
+            var updateText, e, digits,
                 resolvedText,
+                i, that,
                 ev_p = Type.evaluate(this.visProp.parse),
                 ev_um = Type.evaluate(this.visProp.usemathjax),
                 ev_uk = Type.evaluate(this.visProp.usekatex),
@@ -201,13 +211,22 @@ JXG.extend(
             this.orgText = text;
 
             if (Type.isFunction(text)) {
-                // <value> tags will not be evaluated if text is provided by a function
+                /**
+                 * Dynamically created function to update the content
+                 * of a text. Can not be overwritten.
+                 * <p>
+                 * &lt;value&gt; tags will not be evaluated if text is provided by a function
+                 * <p>
+                 * Sets the property <tt>plaintext</tt> of the text element.
+                 *
+                 * @private
+                 */
                 this.updateText = function () {
                     resolvedText = text().toString(); // Evaluate function
                     if (ev_p && !ev_um && !ev_uk) {
                         this.plaintext = this.replaceSub(
                             this.replaceSup(
-                                this.convertGeonextAndSketchometry2CSS(resolvedText)
+                                this.convertGeonextAndSketchometry2CSS(resolvedText, false)
                             )
                         );
                     } else {
@@ -216,16 +235,32 @@ JXG.extend(
                 };
             } else {
                 if (Type.isNumber(text)) {
-                    this.content = Type.toFixed(text, Type.evaluate(this.visProp.digits));
+                    digits = Type.evaluate(this.visProp.digits);
+                    if (this.useLocale()) {
+                        this.content = this.formatNumberLocale(text, digits);
+                    } else {
+                        this.content = Type.toFixed(text, digits);
+                    }
                 } else if (Type.isString(text) && ev_p) {
                     if (Type.evaluate(this.visProp.useasciimathml)) {
                         // ASCIIMathML
+                        // value-tags are not supported
                         this.content = "'`" + text + "`'";
                     } else if (ev_um || ev_uk) {
                         // MathJax or KaTeX
                         // Replace value-tags by functions
+                        // sketchofont is ignored
                         this.content = this.valueTagToJessieCode(text);
-                        this.content = this.content.replace(/\\/g, "\\\\"); // Replace single backshlash by double
+                        if (!Type.isArray(this.content)) {
+                            // For some reason we don't have to mask backslashes in an array of strings
+                            // anymore.
+                            //
+                            // for (i = 0; i < this.content.length; i++) {
+                            //     this.content[i] = this.content[i].replace(/\\/g, "\\\\"); // Replace single backslash by double
+                            // }
+                            // } else {
+                            this.content = this.content.replace(/\\/g, "\\\\"); // Replace single backslash by double
+                        }
                     } else {
                         // No TeX involved.
                         // Converts GEONExT syntax into JavaScript string
@@ -235,24 +270,67 @@ JXG.extend(
                         this.content = this.poorMansTeX(this.valueTagToJessieCode(text));
                     }
                     convertJessieCode = true;
+                } else {
+                    this.content = text;
                 }
 
                 // Generate function which returns the text to be displayed
                 if (convertJessieCode) {
                     // Convert JessieCode to JS function
-                    updateText = this.board.jc.snippet(this.content, true, "", false);
-                    for (e in updateText.deps) {
-                        this.addParents(updateText.deps[e]);
-                        updateText.deps[e].addChild(this);
+                    if (Type.isArray(this.content)) {
+                        // This is the case if the text contained value-tags.
+                        // These value-tags consist of JessieCode snippets
+                        // which are now replaced by JavaScript functions
+                        that = this;
+                        for (i = 0; i < this.content.length; i++) {
+                            if (this.content[i][0] !== '"') {
+                                this.content[i] = this.board.jc.snippet(this.content[i], true, "", false);
+                                for (e in this.content[i].deps) {
+                                    this.addParents(this.content[i].deps[e]);
+                                    this.content[i].deps[e].addChild(this);
+                                }
+                            }
+                        }
+
+                        updateText = function() {
+                            var i, t,
+                                digits = Type.evaluate(that.visProp.digits),
+                                txt = '';
+
+                            for (i = 0; i < that.content.length; i++) {
+                                if (Type.isFunction(that.content[i])) {
+                                    t = that.content[i]();
+                                    if (that.useLocale()) {
+                                        t = that.formatNumberLocale(t, digits);
+                                    } else {
+                                        t = Type.toFixed(t, digits);
+                                    }
+                                } else {
+                                    t = that.content[i];
+                                    if (t.at(0) === '"' && t.at(-1) === '"') {
+                                        t = t.slice(1, -1);
+                                    }
+                                }
+
+                                txt += t;
+                            }
+                            return txt;
+                        };
+                    } else {
+                        updateText = this.board.jc.snippet(this.content, true, "", false);
+                        for (e in updateText.deps) {
+                            this.addParents(updateText.deps[e]);
+                            updateText.deps[e].addChild(this);
+                        }
                     }
 
-                    // Ticks have been esacped in valueTagToJessieCode
+                    // Ticks have been escaped in valueTagToJessieCode
                     this.updateText = function () {
                         this.plaintext = this.unescapeTicks(updateText());
                     };
                 } else {
                     this.updateText = function () {
-                        this.plaintext = text;
+                        this.plaintext = this.content; // text;
                     };
                 }
             }
@@ -609,6 +687,8 @@ JXG.extend(
          * the text is added as child to these objects.
          * This method is called if the attribute parse==true is set.
          *
+         * Obsolete, replaced by JXG.Text.valueTagToJessieCode
+         *
          * @param{String} contentStr String to be parsed
          * @param{Boolean} [expand] Optional flag if shortened math syntax is allowed (e.g. 3x instead of 3*x).
          * @param{Boolean} [avoidGeonext2JS] Optional flag if geonext2JS should be called. For backwards compatibility
@@ -617,8 +697,11 @@ JXG.extend(
          * If true, "_" and "^" are NOT replaced by HTML tags sub and sup. Default: false, i.e. the replacement is done.
          * This flag allows the combination of &lt;value&gt; tag containing calculations with TeX output.
          *
+         * @deprecated
          * @private
-         * @see JXG.GeonextParser.geonext2JS
+         * @see JXG.GeonextParser#geonext2JS
+         * @see JXG.Text#valueTagToJessieCode
+         *
          */
         generateTerm: function (contentStr, expand, avoidGeonext2JS) {
             var res,
@@ -673,21 +756,16 @@ JXG.extend(
                         // output of a value tag
                         if (
                             Type.isNumber(
-                                Type.bind(this.board.jc.snippet(res, true, "", false), this)()
+                                Type.bind(this.board.jc.snippet(res, true, '', false), this)()
                             )
                         ) {
                             // may also be a string
-                            plaintext +=
-                                "+(" +
-                                res +
-                                ").toFixed(" +
-                                Type.evaluate(this.visProp.digits) +
-                                ")";
+                            plaintext += '+(' + res + ').toFixed(' + Type.evaluate(this.visProp.digits) + ')';
                         } else {
-                            plaintext += "+(" + res + ")";
+                            plaintext += '+(' + res + ')';
                         }
                     } else {
-                        plaintext += "+(" + res + ")";
+                        plaintext += '+(' + res + ')';
                     }
 
                     contentStr = contentStr.slice(j + 8);
@@ -706,11 +784,18 @@ JXG.extend(
             return plaintext;
         },
 
+        /**
+         * Replace value-tags in string by JessieCode functions.
+         * @param {String} contentStr
+         * @returns String
+         * @private
+         * @example
+         * "The x-coordinate of A is &lt;value&gt;X(A)&lt;/value&gt;"
+         *
+         */
         valueTagToJessieCode: function (contentStr) {
-            var res,
-                term,
-                i,
-                j,
+            var res, term,
+                i, j,
                 expandShortMath = true,
                 textComps = [],
                 tick = '"';
@@ -738,30 +823,27 @@ JXG.extend(
                     res = term;
                     res = res.replace(/\\"/g, "'").replace(/\\'/g, "'");
 
-                    // Hack: apply rounding once only.
-                    if (res.indexOf("toFixed") < 0) {
-                        // Output of a value tag
-                        // Run the JessieCode parser
-                        if (
-                            Type.isNumber(
-                                Type.bind(this.board.jc.snippet(res, true, "", false), this)()
-                            )
-                        ) {
-                            // Output is number
-                            textComps.push(
-                                "(" +
-                                    res +
-                                    ").toFixed(" +
-                                    Type.evaluate(this.visProp.digits) +
-                                    ")"
-                            );
-                        } else {
-                            // Output is a string
-                            textComps.push("(" + res + ")");
-                        }
-                    } else {
+                    // // Hack: apply rounding once only.
+                    // if (res.indexOf("toFixed") < 0) {
+                    //     // Output of a value tag
+                    //     // Run the JessieCode parser
+                    //     if (
+                    //         Type.isNumber(
+                    //             Type.bind(this.board.jc.snippet(res, true, "", false), this)()
+                    //         )
+                    //     ) {
+                    //         // Output is number
+                    //         // textComps.push(
+                    //         //     '(' + res + ').toFixed(' + Type.evaluate(this.visProp.digits) + ')'
+                    //         // );
+                    //         textComps.push('(' + res + ')');
+                    //     } else {
+                    //         // Output is a string
+                    //         textComps.push("(" + res + ")");
+                    //     }
+                    // } else {
                         textComps.push("(" + res + ")");
-                    }
+                    // }
                     contentStr = contentStr.slice(j + 8);
                     i = contentStr.indexOf("<value>");
                     j = contentStr.indexOf("</value>");
@@ -770,23 +852,63 @@ JXG.extend(
             // Add trailing string fragment
             textComps.push(tick + this.escapeTicks(contentStr) + tick);
 
-            return textComps.join(" + ").replace(/&amp;/g, "&");
+            // return textComps.join(" + ").replace(/&amp;/g, "&");
+            for (i = 0; i < textComps.length; i++) {
+                textComps[i] = textComps[i].replace(/&amp;/g, "&");
+            }
+            return textComps;
         },
 
+        /**
+         * Simple math rendering using HTML / CSS only. In case of array,
+         * handle each entry separately and return array with the
+         * rendering strings.
+         *
+         * @param {String|Array} s
+         * @returns {String|Array}
+         * @see JXG.Text#convertGeonextAndSketchometry2CSS
+         * @private
+         * @see JXG.Text#replaceSub
+         * @see JXG.Text#replaceSup
+         * @see JXG.Text#convertGeonextAndSketchometry2CSS
+         */
         poorMansTeX: function (s) {
+            var i, a;
+            if (Type.isArray(s)) {
+                a = [];
+                for (i = 0; i < s.length; i++) {
+                    a.push(this.poorMansTeX(s[i]));
+                }
+                return a;
+            }
+
             s = s
                 .replace(/<arc\s*\/*>/g, "&ang;")
                 .replace(/&lt;arc\s*\/*&gt;/g, "&ang;")
                 .replace(/<sqrt\s*\/*>/g, "&radic;")
                 .replace(/&lt;sqrt\s*\/*&gt;/g, "&radic;");
-
-            return this.convertGeonextAndSketchometry2CSS(this.replaceSub(this.replaceSup(s)));
+            return this.convertGeonextAndSketchometry2CSS(this.replaceSub(this.replaceSup(s)), true);
         },
 
+        /**
+         * Replace ticks by URI escape sequences
+         *
+         * @param {String} s
+         * @returns String
+         * @private
+         *
+         */
         escapeTicks: function (s) {
             return s.replace(/"/g, "%22").replace(/'/g, "%27");
         },
 
+        /**
+         * Replace escape sequences for ticks by ticks
+         *
+         * @param {String} s
+         * @returns String
+         * @private
+         */
         unescapeTicks: function (s) {
             return s.replace(/%22/g, '"').replace(/%27/g, "'");
         },
@@ -795,7 +917,7 @@ JXG.extend(
          * Converts the GEONExT tags <overline> and <arrow> to
          * HTML span tags with proper CSS formatting.
          * @private
-         * @see JXG.Text.generateTerm
+         * @see JXG.Text.poorMansTeX
          * @see JXG.Text._setText
          */
         convertGeonext2CSS: function (s) {
@@ -818,22 +940,26 @@ JXG.extend(
         /**
          * Converts the sketchometry tag <sketchofont> to
          * HTML span tags with proper CSS formatting.
+         *
+         * @param {String|Function|Number} s Text
+         * @param {Boolean} escape Flag if ticks should be escaped. Escaping is necessary
+         * if s is a text. It has to be avoided if s is a function returning text.
          * @private
-         * @see JXG.Text.generateTerm
          * @see JXG.Text._setText
+         * @see JXG.Text.convertGeonextAndSketchometry2CSS
+         *
          */
-        convertSketchometry2CSS: function (s) {
+        convertSketchometry2CSS: function (s, escape) {
+            var t1 = "<span class=\"sketcho sketcho-inherit sketcho-",
+                t2 = "\"></span>";
+
             if (Type.isString(s)) {
-                s = s.replace(
-                    /(<|&lt;)sketchofont(>|&gt;)/g,
-                    "<span style=font-family:sketchometry-light;font-weight:500;>"
-                );
-                s = s.replace(/(<|&lt;)\/sketchofont(>|&gt;)/g, "</span>");
-                s = s.replace(
-                    /(<|&lt;)sketchometry-light(>|&gt;)/g,
-                    "<span style=font-family:sketchometry-light;font-weight:500;>"
-                );
-                s = s.replace(/(<|&lt;)\/sketchometry-light(>|&gt;)/g, "</span>");
+                if (escape) {
+                    t1 = this.escapeTicks(t1);
+                    t2 = this.escapeTicks(t2);
+                }
+                s = s.replace(/(<|&lt;)sketchofont(>|&gt;)/g, t1);
+                s = s.replace(/(<|&lt;)\/sketchofont(>|&gt;)/g, t2);
             }
 
             return s;
@@ -841,13 +967,16 @@ JXG.extend(
 
         /**
          * Alias for convertGeonext2CSS and convertSketchometry2CSS
+         *
+         * @param {String|Function|Number} s Text
+         * @param {Boolean} escape Flag if ticks should be escaped
          * @private
          * @see JXG.Text.convertGeonext2CSS
          * @see JXG.Text.convertSketchometry2CSS
          */
-        convertGeonextAndSketchometry2CSS: function (s) {
+        convertGeonextAndSketchometry2CSS: function (s, escape) {
             s = this.convertGeonext2CSS(s);
-            s = this.convertSketchometry2CSS(s);
+            s = this.convertSketchometry2CSS(s, escape);
             return s;
         },
 
@@ -901,6 +1030,17 @@ JXG.extend(
             return p;
         },
 
+        /**
+         * Returns the bounding box of the text element in user coordinates as an
+         * array of length 4: [upper left x, upper left y, lower right x, lower right y].
+         * The method assumes that the lower left corner is at position [el.X(), el.Y()]
+         * of the text element el, i.e. the attributes anchorX, anchorY are ignored.
+         *
+         * <p>
+         * or labels, [0, 0, 0, 0] is returned.
+         *
+         * @returns Array
+         */
         bounds: function () {
             var c = this.coords.usrCoords;
 
@@ -919,6 +1059,12 @@ JXG.extend(
             ];
         },
 
+        /**
+         * Returns the value of the attribute "anchorX". If this equals "auto",
+         * returns "left", "middle", or "right", depending on the
+         * value of the attribute "position".
+         * @returns String
+         */
         getAnchorX: function () {
             var a = Type.evaluate(this.visProp.anchorx);
             if (a === "auto") {
@@ -940,6 +1086,12 @@ JXG.extend(
             return a;
         },
 
+        /**
+         * Returns the value of the attribute "anchorY". If this equals "auto",
+         * returns "bottom", "middle", or "top", depending on the
+         * value of the attribute "position".
+         * @returns String
+         */
         getAnchorY: function () {
             var a = Type.evaluate(this.visProp.anchory);
             if (a === "auto") {
@@ -1124,10 +1276,18 @@ JXG.extend(
 /**
  * @class Construct and handle texts.
  *
- * The coordinates can be relative to the coordinates of an element
- * given in {@link JXG.Options#text.anchor}.
- *
- * MathJaX, HTML and GEONExT syntax can be handled.
+ * The coordinates can either be abslute (i.e. respective to the coordinate system of the board) or be relative to the coordinates of an element
+ * given in {@link Text#anchor}.
+ * <p>
+ * HTML, MathJaX, KaTeX and GEONExT syntax can be handled.
+ * <p>
+ * There are two ways to display texts:
+ * <ul>
+ * <li> using the text element of the renderer (canvas or svg). In most cases this is the suitable approach if speed matters.
+ * However, advanced rendering like MathJax, KaTeX or HTML/CSS are not possible.
+ * <li> using HTML &lt;div&gt;. This is the most flexible approach. The drawback is that HTML can only be display "above" the geometry elements.
+ * If HTML should be displayed in an inbetween layer, conder to use an element of type {@link ForeignObject} (available in svg renderer, only).
+ * </ul>
  * @pseudo
  * @description
  * @name Text
@@ -1138,7 +1298,8 @@ JXG.extend(
  * @param {number,function_number,function_number,function_String,function} z_,x,y,str Parent elements for text elements.
  *                     <p>
  *   Parent elements can be two or three elements of type number, a string containing a GEONE<sub>x</sub>T
- *   constraint, or a function which takes no parameter and returns a number. Every parent element determines one coordinate. If a coordinate is
+ *   constraint, or a function which takes no parameter and returns a number. Every parent element beside the last determines one coordinate.
+ *   If a coordinate is
  *   given by a number, the number determines the initial position of a free text. If given by a string or a function that coordinate will be constrained
  *   that means the user won't be able to change the texts's position directly by mouse because it will be calculated automatically depending on the string
  *   or the function's return value. If two parent elements are given the coordinates will be interpreted as 2D affine Euclidean coordinates, if three such
@@ -1146,8 +1307,11 @@ JXG.extend(
  *                     <p>
  *                     The text to display may be given as string or as function returning a string.
  *
- * There is the attribute 'display' which takes the values 'html' or 'internal'. In case of 'html' a HTML division tag is created to display
- * the text. In this case it is also possible to use ASCIIMathML. Incase of 'internal', a SVG or VML text element is used to display the text.
+ * There is the attribute 'display' which takes the values 'html' or 'internal'. In case of 'html' an HTML division tag is created to display
+ * the text. In this case it is also possible to use MathJax, KaTeX, or ASCIIMathML. If neither of these is used, basic Math rendering is
+ * applied.
+ * <p>
+ * In case of 'internal', an SVG text element is used to display the text.
  * @see JXG.Text
  * @example
  * // Create a fixed text at position [0,1].
@@ -1210,7 +1374,7 @@ JXG.createText = function (board, parents, attributes) {
         );
     }
 
-    if (attr.rotate !== 0 && attr.display === "internal") {
+    if (attr.rotate !== 0) {
         // This is the default value, i.e. no rotation
         t.addRotation(attr.rotate);
     }
