@@ -112,6 +112,11 @@ JXG.createTapemeasure = function (board, parents, attributes) {
             n = "";
         }
         li.label.setText(function () {
+            var digits = Type.evaluate(li.label.visProp.digits);
+
+            if (li.label.useLocale()) {
+                return n + li.label.formatNumberLocale(p1.Dist(p2), digits);
+            }
             return n + Type.toFixed(p1.Dist(p2), digits);
         });
     }
