@@ -135,7 +135,7 @@ import Type from "../utils/type";
  * var A = board.create('point', [3, -2]),
  *     B = board.create('point', [-2, -2]),
  *     C = board.create('point', [0, 4]);
- * 
+ *
  * var angle = board.create('sector', [B, A, C], {
  *         strokeWidth: 0,
  *         arc: {
@@ -147,7 +147,7 @@ import Type from "../utils/type";
  *       });
  * //angle.arc.setAttribute({firstArrow: false});
  * angle.arc.setAttribute({lastArrow: false});
- * 
+ *
  * </pre><div id="JXGca37b99e-1510-49fa-ac9e-efd60e956104" class="jxgbox" style="width: 300px; height: 300px;"></div>
  * <script type="text/javascript">
  *     (function() {
@@ -156,7 +156,7 @@ import Type from "../utils/type";
  *     var A = board.create('point', [3, -2]),
  *         B = board.create('point', [-2, -2]),
  *         C = board.create('point', [0, 4]);
- *     
+ *
  *     var angle = board.create('sector', [B, A, C], {
  *             strokeWidth: 0,
  *             arc: {
@@ -168,12 +168,12 @@ import Type from "../utils/type";
  *           });
  *     //angle.arc.setAttribute({firstArrow: false});
  *     angle.arc.setAttribute({lastArrow: false});
- * 
+ *
  *     })();
- * 
+ *
  * </script><pre>
- * 
- * 
+ *
+ *
  */
 JXG.createSector = function (board, parents, attributes) {
     var el,
@@ -216,12 +216,16 @@ JXG.createSector = function (board, parents, attributes) {
     el.elType = "sector";
 
     /**
-     * Set a radius if the attribute `radius` has value 'auto'.
+     * Sets radius if the attribute `radius` has value 'auto'.
      * Sets a radius between 20 and 50 points, depending on the distance
      * between the center and the radius point.
      * This function is used in {@link Angle}.
      *
+     * @name autoRadius
+     * @memberof Sector.prototype
+     * @function
      * @returns {Number} returns a radius value in user coordinates.
+     * @private
      */
     el.autoRadius = function () {
         var r1 = 20 / el.board.unitX, // 20px
@@ -526,7 +530,7 @@ JXG.createSector = function (board, parents, attributes) {
             // 'inherit'
             prec = this.board.options.precision.hasPoint;
         }
-        prec /= Math.min(this.board.unitX, this.board.unitY);
+        prec /= Math.min(Math.abs(this.board.unitX), Math.abs(this.board.unitY));
         has = Math.abs(dist - r) < prec;
         if (has) {
             angle = Geometry.rad(this.point2, this.center, checkPoint.usrCoords.slice(1));
@@ -655,6 +659,22 @@ JXG.createSector = function (board, parents, attributes) {
      * @param {Number, Function} value New radius.
      */
     el.setRadius = function (val) {
+        var res,
+            e = Type.evaluate(val);
+
+        if (val === 'auto' || e === 'auto') {
+            res = 'auto';
+        } else if (Type.isNumber(val)) {
+            res = 'number';
+        } else if (Type.isFunction(val) && !Type.isString(e)) {
+            res = 'function';
+        } else {
+            res = 'undefined';
+        }
+        if (res !== 'undefined') {
+            this.visProp.radius = val;
+        }
+
         /**
          * @ignore
          */
@@ -810,12 +830,12 @@ JXG.registerElement("circumcirclesector", JXG.createCircumcircleSector);
  *       a = board.create('minorsector', [p1, p2, p3]);
  * })();
  * </script><pre>
- * 
+ *
  * @example
  * var A = board.create('point', [3, -2]),
  *     B = board.create('point', [-2, -2]),
  *     C = board.create('point', [0, 4]);
- * 
+ *
  * var angle = board.create('minorsector', [B, A, C], {
  *         strokeWidth: 0,
  *         arc: {
@@ -827,8 +847,8 @@ JXG.registerElement("circumcirclesector", JXG.createCircumcircleSector);
  *       });
  * //angle.arc.setAttribute({firstArrow: false});
  * angle.arc.setAttribute({lastArrow: false});
- * 
- * 
+ *
+ *
  * </pre><div id="JXGdddf3c8f-4b0c-4268-8171-8fcd30e71f60" class="jxgbox" style="width: 300px; height: 300px;"></div>
  * <script type="text/javascript">
  *     (function() {
@@ -837,7 +857,7 @@ JXG.registerElement("circumcirclesector", JXG.createCircumcircleSector);
  *     var A = board.create('point', [3, -2]),
  *         B = board.create('point', [-2, -2]),
  *         C = board.create('point', [0, 4]);
- *     
+ *
  *     var angle = board.create('minorsector', [B, A, C], {
  *             strokeWidth: 0,
  *             arc: {
@@ -849,12 +869,12 @@ JXG.registerElement("circumcirclesector", JXG.createCircumcircleSector);
  *           });
  *     //angle.arc.setAttribute({firstArrow: false});
  *     angle.arc.setAttribute({lastArrow: false});
- *     
- * 
+ *
+ *
  *     })();
- * 
+ *
  * </script><pre>
- * 
+ *
  */
 JXG.createMinorSector = function (board, parents, attributes) {
     attributes.selection = "minor";
@@ -1033,11 +1053,8 @@ JXG.registerElement("majorsector", JXG.createMajorSector);
  */
 JXG.createAngle = function (board, parents, attributes) {
     var el,
-        radius,
-        attr,
-        attrsub,
-        i,
-        points,
+        radius, attr, attrsub,
+        i, points,
         type = "invalid";
 
     // Two lines or three points?
@@ -1049,7 +1066,10 @@ JXG.createAngle = function (board, parents, attributes) {
     ) {
         type = "2lines";
     } else {
-        points = Type.providePoints(board, parents, attributes, "point");
+        attr = {
+            name: ''
+        }
+        points = Type.providePoints(board, parents, attr, "point");
         if (points === false) {
             throw new Error(
                 "JSXGraph: Can't create angle with parent types '" +
@@ -1164,10 +1184,10 @@ JXG.createAngle = function (board, parents, attributes) {
          * </pre>
          *
          * @name setAngle
+         * @memberof Angle.prototype
          * @function
          * @param {Number|Function} val Number or Function which returns the size of the angle in Radians
          * @returns {Object} Pointer to the angle element..
-         * @memberOf Angle.prototype
          * @see Angle#free
          *
          * @example
@@ -1254,8 +1274,7 @@ JXG.createAngle = function (board, parents, attributes) {
          *
          */
         el.setAngle = function (val) {
-            var t1,
-                t2,
+            var t1, t2,
                 val2,
                 p = this.anglepoint,
                 q = this.radiuspoint;
@@ -1303,8 +1322,8 @@ JXG.createAngle = function (board, parents, attributes) {
          * "setAngle()" previously. The anglepoint is set to a free point.
          * @name free
          * @function
+         * @memberof Angle.prototype
          * @returns {Object} Pointer to the angle element..
-         * @memberOf Angle.prototype
          * @see Angle#setAngle
          */
         el.free = function () {
@@ -1334,15 +1353,9 @@ JXG.createAngle = function (board, parents, attributes) {
     el.subs = {};
 
     el.updateDataArraySquare = function () {
-        var A,
-            B,
-            C,
-            r = this.Radius(),
-            d1,
-            d2,
-            v,
-            l1,
-            l2;
+        var A, B, C,
+            d1, d2, v, l1, l2,
+            r = this.Radius();
 
         if (type === "2lines") {
             // This is necessary to update this.point1, this.point2, this.point3.
@@ -1416,6 +1429,7 @@ JXG.createAngle = function (board, parents, attributes) {
         }
     };
 
+    attrsub = Type.copyAttributes(attributes, board.options, "angle", "dot");
     /**
      * Indicates a right angle. Invisible by default, use <tt>dot.visible: true</tt> to show.
      * Though this dot indicates a right angle, it can be visible even if the angle is not a right
@@ -1424,7 +1438,6 @@ JXG.createAngle = function (board, parents, attributes) {
      * @name dot
      * @memberOf Angle.prototype
      */
-    attrsub = Type.copyAttributes(attributes, board.options, "angle", "dot");
     el.dot = board.create(
         "point",
         [
@@ -1480,14 +1493,7 @@ JXG.createAngle = function (board, parents, attributes) {
     el.getLabelAnchor = function () {
         var vec,
             dx = 12,
-            A,
-            B,
-            r,
-            d,
-            a2,
-            co,
-            si,
-            mat,
+            A, B, r, d, a2, co, si, mat,
             vp_s = Type.evaluate(el.visProp.selection),
             l_vp = this.label ? this.label.visProp : this.visProp.label;
 
@@ -1496,8 +1502,8 @@ JXG.createAngle = function (board, parents, attributes) {
         //    this.label.relativeCoords = new Coords(Const.COORDS_BY_SCREEN, [0, 0], this.board);
         //}
 
-        if (Type.exists(this.label.visProp.fontSize)) {
-            dx = Type.evaluate(this.label.visProp.fontSize);
+        if (Type.exists(this.label) && Type.exists(this.label.visProp.fontsize)) {
+            dx = Type.evaluate(this.label.visProp.fontsize);
         }
         dx /= this.board.unitX;
 
@@ -1596,6 +1602,7 @@ JXG.createNonreflexAngle = function (board, parents, attributes) {
     var el;
 
     attributes.selection = "minor";
+    attributes = Type.copyAttributes(attributes, board.options, 'nonreflexangle');
     el = JXG.createAngle(board, parents, attributes);
 
     // Documented in createAngle
@@ -1645,6 +1652,7 @@ JXG.createReflexAngle = function (board, parents, attributes) {
     var el;
 
     attributes.selection = "major";
+    attributes = Type.copyAttributes(attributes, board.options, 'reflexangle');
     el = JXG.createAngle(board, parents, attributes);
 
     // Documented in createAngle
