@@ -261,6 +261,7 @@ JXG.createSlider = function (board, parents, attributes) {
     /**
      * Sets the maximum value of the slider.
      * @memberOf Slider.prototype
+     * @function
      * @name setMax
      * @param {Number} val New maximum value
      * @returns {Object} this object
@@ -275,6 +276,7 @@ JXG.createSlider = function (board, parents, attributes) {
      * by a board update call.
      * @memberOf Slider.prototype
      * @name setValue
+     * @function
      * @param {Number} val New value
      * @returns {Object} this object
      */
@@ -294,6 +296,7 @@ JXG.createSlider = function (board, parents, attributes) {
      * Sets the minimum value of the slider.
      * @memberOf Slider.prototype
      * @name setMin
+     * @function
      * @param {Number} val New minimum value
      * @returns {Object} this object
      */
@@ -303,10 +306,8 @@ JXG.createSlider = function (board, parents, attributes) {
     };
 
     if (withText) {
-        attr = Type.copyAttributes(attributes, board.options, "slider", "label");
-        t = board.create(
-            "text",
-            [
+        attr = Type.copyAttributes(attributes, board.options, 'slider', 'label');
+        t = board.create('text', [
                 function () {
                     return (p2.X() - p1.X()) * 0.05 + p2.X();
                 },
@@ -333,7 +334,11 @@ JXG.createSlider = function (board, parents, attributes) {
                         n = "";
                     }
 
-                    n += Type.toFixed(p3.Value(), d);
+                    if (p3.useLocale()) {
+                        n += p3.formatNumberLocale(p3.Value(), d);
+                    } else {
+                        n += Type.toFixed(p3.Value(), d);
+                    }
 
                     if (ul !== null) {
                         n += ul;
