@@ -69,6 +69,8 @@ import "./element/slopetriangle";
 import "./element/checkbox";
 import "./element/input";
 import "./element/button";
+import "./element/vectorfield";
+import "./element/smartlabel";
 import "./base/foreignobject";
 import "./options3d";
 import "./3d/view3d";
@@ -89,7 +91,7 @@ export const COORDS_BY_SCREEN = JXG.COORDS_BY_SCREEN;
 export const COORDS_BY_USER = JXG.COORDS_BY_USER;
 export const Dump = JXG.Dump;
 export const JSXGraph = JXG.JSXGraph;
-export const Math = JXG.Math;
+export const Mat = JXG.Math;
 export const Options = JXG.Options;
 export const boards = JXG.boards;
 export const elements = JXG.elements;
@@ -162,6 +164,7 @@ export const isInArray = JXG.isInArray;
 export const isInObject = JXG.isInObject;
 export const isMetroApp = JXG.isMetroApp;
 export const isMozilla = JXG.isMozilla;
+export const isBoard = JXG.isBoard;
 export const isName = JXG.isName;
 export const isNode = JXG.isNode;
 export const isNumber = JXG.isNumber;
