@@ -42,6 +42,7 @@
 import JXG from "./jxg";
 import Env from "./utils/env";
 import Type from "./utils/type";
+import Mat from "./math/math";
 import Board from "./base/board";
 import FileReader from "./reader/file";
 import Options from "./options";
@@ -118,7 +119,7 @@ JXG.JSXGraph = {
      * @param  {Object} dim        The dimensions of the board
      * @param  {Object} doc        Usually, this is document object of the browser window.  If false or null, this defaults
      * to the document object of the browser.
-     * @param  {Object} attrRenderer Attribute 'renderer', speficies the rendering engine. Possible values are 'auto', 'svg',
+     * @param  {Object} attrRenderer Attribute 'renderer', specifies the rendering engine. Possible values are 'auto', 'svg',
      *  'canvas', 'no', and 'vml'.
      * @returns {Object}           Reference to the rendering engine object.
      * @private
@@ -171,19 +172,23 @@ JXG.JSXGraph = {
      */
     _setAttributes: function (attributes) {
         // merge attributes
-        var attr = Type.copyAttributes(attributes, Options, "board");
+        var attr = Type.copyAttributes(attributes, Options, 'board'),
 
-        // The attributes which are objects have to be copied separately
-        attr.zoom = Type.copyAttributes(attr, Options, "board", "zoom");
-        attr.pan = Type.copyAttributes(attr, Options, "board", "pan");
-        attr.drag = Type.copyAttributes(attr, Options, "board", "drag");
-        attr.keyboard = Type.copyAttributes(attr, Options, "board", "keyboard");
-        attr.selection = Type.copyAttributes(attr, Options, "board", "selection");
-        attr.navbar = Type.copyAttributes(attr.navbar, Options, "navbar");
-        attr.screenshot = Type.copyAttributes(attr, Options, "board", "screenshot");
-        attr.resize = Type.copyAttributes(attr, Options, "board", "resize");
-        attr.fullscreen = Type.copyAttributes(attr, Options, "board", "fullscreen");
-        attr.logging = Type.copyAttributes(attr, Options, 'board', 'logging');
+            // These attributes - which are objects - have to be copied separately.
+            list = [
+                'drag', 'fullscreen',
+                'intl',
+                'keyboard', 'logging',
+                'navbar', 'pan', 'resize',
+                'screenshot', 'selection',
+                'zoom'
+            ],
+            len = list.length, i, key;
+
+        for (i = 0; i < len; i++) {
+            key = list[i];
+            attr[key] = Type.copyAttributes(attr, Options, 'board', key);
+        }
 
         // Treat moveTarget separately, because deepCopy will not work here.
         // Reason: moveTarget will be an HTML node and it is prevented that Type.deepCopy will copy it.
@@ -203,18 +208,18 @@ JXG.JSXGraph = {
      * @private
      */
     _fillBoard: function (board, attr, dimensions) {
-        board.initInfobox();
+        board.initInfobox(attr.infobox);
         board.maxboundingbox = attr.maxboundingbox;
         board.resizeContainer(dimensions.width, dimensions.height, true, true);
         board._createSelectionPolygon(attr);
-        board.renderer.drawZoomBar(board, attr.navbar);
+        board.renderer.drawNavigationBar(board, attr.navbar);
         JXG.boards[board.id] = board;
     },
 
     /**
      *
      * @param {String} container HTML-ID to the HTML-element in which the board is painted.
-     * @param {*} attr An object that sets some of the board properties.
+     * @param {Object} attr An object that sets some of the board properties.
      *
      * @private
      */
@@ -285,7 +290,7 @@ JXG.JSXGraph = {
     },
 
     /**
-     * Initialise a new board.
+     * Initialize a new board.
      * @param {String} box HTML-ID to the HTML-element in which the board is painted.
      * @param {Object} attributes An object that sets some of the board properties. Most of these properties can be set via JXG.Options.
      * @param {Array} [attributes.boundingbox=[-5, 5, 5, -5]] An array containing four numbers describing the left, top, right and bottom boundary of the board in user coordinates
@@ -301,24 +306,13 @@ JXG.JSXGraph = {
      * @param {Boolean} [attributes.registerEvents=true] Register mouse / touch events.
      * @returns {JXG.Board} Reference to the created board.
      *
-     * @see JXG.AbstractRenderer#drawZoomBar
+     * @see JXG.AbstractRenderer#drawNavigationBar
      */
     initBoard: function (box, attributes) {
-        var originX,
-            originY,
-            unitX,
-            unitY,
-            renderer,
-            offX = 0,
-            offY = 0,
-            w,
-            h,
-            dimensions,
-            bbox,
-            attr,
-            axattr,
-            axattr_x,
-            axattr_y,
+        var originX, originY, unitX, unitY, w, h,
+            offX = 0, offY = 0,
+            renderer, dimensions, bbox,
+            attr, axattr, axattr_x, axattr_y,
             board;
 
         attributes = attributes || {};
@@ -346,8 +340,11 @@ JXG.JSXGraph = {
                 bbox[3] = attr.maxboundingbox[3];
             }
 
-            w = parseInt(dimensions.width, 10);
-            h = parseInt(dimensions.height, 10);
+            // Size of HTML div.
+            // If zero, the size is set to a small value to avoid
+            // division by zero.
+            w = Math.max(parseInt(dimensions.width, 10), Mat.eps);
+            h = Math.max(parseInt(dimensions.height, 10), Mat.eps);
 
             if (Type.exists(bbox) && attr.keepaspectratio) {
                 /*
@@ -384,8 +381,8 @@ JXG.JSXGraph = {
             renderer,
             attr.id,
             [originX, originY],
-            attr.zoomfactor * attr.zoomx,
-            attr.zoomfactor * attr.zoomy,
+            /*attr.zoomfactor * */ attr.zoomx,
+            /*attr.zoomfactor * */ attr.zoomy,
             unitX,
             unitY,
             dimensions.width,
@@ -609,31 +606,15 @@ JXG.JSXGraph = {
 };
 
 // JessieScript/JessieCode startup:
-// Search for script tags of type text/jessiescript and interprete them.
-if (Env.isBrowser && typeof window === "object" && typeof document === "object") {
-    Env.addEvent(
-        window,
-        "load",
+// Search for script tags of type text/jessiecode and execute them.
+if (Env.isBrowser && typeof window === 'object' && typeof document === 'object') {
+    Env.addEvent(window, 'load',
         function () {
-            var type,
-                i,
-                j,
-                div,
-                id,
-                board,
-                txt,
-                width,
-                height,
-                maxWidth,
-                aspectRatio,
-                cssClasses,
-                bbox,
-                axis,
-                grid,
-                code,
-                src,
-                request,
+            var type, i, j, div, id,
+                board, txt, width, height, maxWidth, aspectRatio,
+                cssClasses, bbox, axis, grid, code, src, request,
                 postpone = false,
+
                 scripts = document.getElementsByTagName("script"),
                 init = function (code, type, bbox) {
                     var board = JXG.JSXGraph.initBoard(id, {
