@@ -150,13 +150,46 @@ JXG.AbstractRenderer = function () {
 
     /**
      * True if the browsers' SVG engine supports foreignObject.
-     * Not supported browsers are IE 9 - 11. 
+     * Not supported browsers are IE 9 - 11.
      * It is tested in svg renderer.
      *
      * @type Boolean
      * @private
      */
     this.supportsForeignObject = false;
+
+    /**
+     * Defines dash patterns. Sizes are in pixel.
+     * Defined styles are:
+     * <ol>
+     * <li> 2 dash, 2 space</li>
+     * <li> 5 dash, 5 space</li>
+     * <li> 10 dash, 10 space</li>
+     * <li> 20 dash, 20 space</li>
+     * <li> 20 dash, 10 space, 10 dash, 10 space</li>
+     * <li> 20 dash, 5 space, 10 dash, 5 space</li>
+     * <li> 0 dash, 5 space (dotted line)</li>
+     * </ol>
+     * This means, the numbering is <b>1-based</b>.
+     * Solid lines are set with dash:0.
+     * If the object's attribute "dashScale:true" the dash pattern is multiplied by
+     * strokeWidth / 2.
+     *
+     * @type Array
+     * @default [[2, 2], [5, 5], [10, 10], [20, 20], [20, 10, 10, 10], [20, 5, 10, 5], [0, 5]]
+     * @see JXG.GeometryElement#dash
+     * @see JXG.GeometryElement#dashScale
+     */
+    this.dashArray = [
+        [2, 2],
+        [5, 5],
+        [10, 10],
+        [20, 20],
+        [20, 10, 10, 10],
+        [20, 5, 10, 5],
+        [0, 5]
+    ];
+
 };
 
 JXG.extend(
@@ -224,9 +257,10 @@ JXG.extend(
                         this.setShadow(el);
                     }
 
-                    if (!not.gradient) {
-                        this.setShadow(el);
-                    }
+                    // if (!not.gradient) {
+                    //     // this.setGradient(el);
+                    //     this.setShadow(el);
+                    // }
 
                     if (!not.tabindex) {
                         this.setTabindex(el);
@@ -285,7 +319,7 @@ JXG.extend(
             } else if (face === "[]") {
                 prim = "rect";
             } else {
-                // cross/x, diamond/<>, triangleup/a/^, triangledown/v, triangleleft/<,
+                // cross/x, diamond/<>, triangleup/A/^, triangledown/v, triangleleft/<,
                 // triangleright/>, plus/+, |, -
                 prim = "path";
             }
@@ -323,7 +357,7 @@ JXG.extend(
 
             if (!isNaN(el.coords.scrCoords[2] + el.coords.scrCoords[1])) {
                 if (unit === "user") {
-                    size *= Math.sqrt(el.board.unitX * el.board.unitY);
+                    size *= Math.sqrt(Math.abs(el.board.unitX * el.board.unitY));
                 }
                 size *= !el.board || !zoom ? 1.0 : Math.sqrt(el.board.zoomX * el.board.zoomY);
                 s1 = size === 0 ? 0 : size + 1;
@@ -479,7 +513,7 @@ JXG.extend(
          */
         updatePathWithArrowHeads: function (el, doHighlight) {
             var ev = el.visProp,
-                hl = doHighlight ? "highlight" : "",
+                hl = doHighlight ? 'highlight' : '',
                 w,
                 arrowData;
 
@@ -709,26 +743,24 @@ JXG.extend(
          * Shorten the length of a line element such that the arrow head touches
          * the start or end point and such that the arrow head ends exactly
          * at the start / end position of the line.
+         * <p>
+         * The Coords objects c1 and c2 are changed in place. In object a, the Boolean properties
+         * 'showFirst' and 'showLast' are set.
          *
          * @param  {JXG.Line} el Reference to the line object that gets arrow heads.
          * @param  {JXG.Coords} c1  Coords of the first point of the line (after {@link JXG.Math.Geometry#calcStraight}).
          * @param  {JXG.Coords} c2  Coords of the second point of the line (after {@link JXG.Math.Geometry#calcStraight}).
-         * @param  {Object}  a
-         * @return {object} Object containing how much the line has to be shortened.
-         * Data structure: {c1, c2, d1x, d1y, d2x, d2y, sFirst, sLast}. sFirst and sLast is the length by which
-         * firstArrow and lastArrow have to shifted such that there is no gap between arrow head and line.
-         * Additionally, if one of these values is zero, the arrow is not displayed. This is the case, if the
-         * line length is very short.
+         * @param  {Object}  a Object { evFirst: Boolean, evLast: Boolean} containing information about arrow heads.
+         * @see JXG.AbstractRenderer#getArrowHeadData
+         *
          */
         getPositionArrowHead: function (el, c1, c2, a) {
             var d, d1x, d1y, d2x, d2y;
 
-            /*
-               Handle arrow heads.
+            //    Handle arrow heads.
 
-               The default arrow head (type==1) is an isosceles triangle with base length 10 units and height 10 units.
-               These 10 units are scaled to strokeWidth * arrowSize pixels.
-            */
+            //    The default arrow head (type==1) is an isosceles triangle with base length 10 units and height 10 units.
+            //    These 10 units are scaled to strokeWidth * arrowSize pixels.
             if (a.evFirst || a.evLast) {
                 // Correct the position of the arrow heads
                 d1x = d1y = d2x = d2y = 0.0;
@@ -775,6 +807,7 @@ JXG.extend(
          * @param {JXG.Coords} c1 Coordinates of the start of the line. The coordinates are changed in place.
          * @param {JXG.Coords} c2 Coordinates of the end of the line. The coordinates are changed in place.
          * @param {Object} a
+         * @see JXG.AbstractRenderer#getArrowHeadData
          */
         handleTouchpoints: function (el, c1, c2, a) {
             var s1, s2, d, d1x, d1y, d2x, d2y;
@@ -782,22 +815,23 @@ JXG.extend(
             if (a.evFirst || a.evLast) {
                 d = d1x = d1y = d2x = d2y = 0.0;
 
-                s1 =
-                    Type.evaluate(el.point1.visProp.size) +
+                s1 = Type.evaluate(el.point1.visProp.size) +
                     Type.evaluate(el.point1.visProp.strokewidth);
-                s2 =
-                    Type.evaluate(el.point2.visProp.size) +
+
+                s2 = Type.evaluate(el.point2.visProp.size) +
                     Type.evaluate(el.point2.visProp.strokewidth);
 
                 // Handle touchlastpoint /touchfirstpoint
-                if (a.evFirst && Type.evaluate(el.visProp.touchfirstpoint)) {
+                if (a.evFirst && Type.evaluate(el.visProp.touchfirstpoint) &&
+                        Type.evaluate(el.point1.visProp.visible)) {
                     d = c1.distance(Const.COORDS_BY_SCREEN, c2);
                     //if (d > s) {
                     d1x = ((c2.scrCoords[1] - c1.scrCoords[1]) * s1) / d;
                     d1y = ((c2.scrCoords[2] - c1.scrCoords[2]) * s1) / d;
                     //}
                 }
-                if (a.evLast && Type.evaluate(el.visProp.touchlastpoint)) {
+                if (a.evLast && Type.evaluate(el.visProp.touchlastpoint) &&
+                        Type.evaluate(el.point2.visProp.visible)) {
                     d = c1.distance(Const.COORDS_BY_SCREEN, c2);
                     //if (d > s) {
                     d2x = ((c2.scrCoords[1] - c1.scrCoords[1]) * s2) / d;
@@ -939,11 +973,9 @@ JXG.extend(
             var radius = el.Radius();
 
             if (
-                radius > 0.0 &&
+                /*radius > 0.0 &&*/
                 Math.abs(el.center.coords.usrCoords[0]) > Mat.eps &&
-                !isNaN(
-                    radius + el.center.coords.scrCoords[1] + el.center.coords.scrCoords[2]
-                ) &&
+                !isNaN(radius + el.center.coords.scrCoords[1] + el.center.coords.scrCoords[2]) &&
                 radius * el.board.unitX < 2000000
             ) {
                 this.updateEllipsePrim(
@@ -954,6 +986,7 @@ JXG.extend(
                     radius * el.board.unitY
                 );
             }
+            this.setLineCap(el);
         },
 
         /* **************************
@@ -1101,15 +1134,12 @@ JXG.extend(
          */
         updateText: function (el) {
             var content = el.plaintext,
-                v,
-                c,
+                v, c,
                 parentNode,
-                scale,
-                vshift,
-                id,
-                wrap_id,
-                ax,
-                ay;
+                scale, vshift,
+                id, wrap_id,
+                ax, ay, angle, co, si,
+                to_h, to_v;
 
             if (el.visPropCalc.visible) {
                 this.updateTextStyle(el, false);
@@ -1126,13 +1156,16 @@ JXG.extend(
                         if (ax === "right") {
                             // v = Math.floor(el.board.canvasWidth - c);
                             v = el.board.canvasWidth - c;
+                            to_h = "right";
                         } else if (ax === "middle") {
                             // v = Math.floor(c - 0.5 * el.size[0]);
                             v = c - 0.5 * el.size[0];
+                            to_h = "center";
                         } else {
                             // 'left'
                             // v = Math.floor(c);
                             v = c;
+                            to_h = "left";
                         }
 
                         // This may be useful for foreignObj.
@@ -1159,13 +1192,16 @@ JXG.extend(
                         if (ay === "bottom") {
                             // v = Math.floor(el.board.canvasHeight - c);
                             v = el.board.canvasHeight - c;
+                            to_v = "bottom";
                         } else if (ay === "middle") {
                             // v = Math.floor(c - 0.5 * el.size[1]);
                             v = c - 0.5 * el.size[1];
+                            to_v = "center";
                         } else {
                             // top
                             // v = Math.floor(c);
                             v = c;
+                            to_v = "top";
                         }
 
                         // This may be useful for foreignObj.
@@ -1242,6 +1278,7 @@ JXG.extend(
                             try {
                                 /* eslint-disable no-undef */
                                 katex.render(content, el.rendNode, {
+                                    macros: Type.evaluate(el.visProp.katexmacros),
                                     throwOnError: false
                                 });
                                 /* eslint-enable no-undef */
@@ -1259,6 +1296,19 @@ JXG.extend(
                             }
                         }
                     }
+
+                    angle = Type.evaluate(el.visProp.rotate);
+                    if (angle !== 0) {
+                        // Don't forget to convert to rad
+                        angle *= (Math.PI / 180);
+                        co = Math.cos(angle);
+                        si = Math.sin(angle);
+
+                        el.rendNode.style['transform'] = 'matrix(' +
+                                [co, -1 * si, si, co, 0, 0].join(',') +
+                            ')';
+                        el.rendNode.style['transform-origin'] = to_h + ' ' + to_v;
+                    }
                     this.transformImage(el, el.transformations);
                 } else {
                     this.updateInternalText(el);
@@ -1396,6 +1446,8 @@ JXG.extend(
                 }
             }
 
+            this.setTabindex(el);
+
             this.setObjectTransition(el);
             if (display === "html" && this.type !== "no") {
                 // Set new CSS class
@@ -1525,8 +1577,12 @@ JXG.extend(
         },
 
         /**
-         * Applies transformations on images and text elements. This method is just a stub and has to be implemented in
+         * Applies transformations on images and text elements. This method has to implemented in
          * all descendant classes where text and image transformations are to be supported.
+         * <p>
+         * Only affine transformation are supported, no proper projective transformations. This means, the 
+         * respective entries of the transformation matrix are simply ignored.
+         * 
          * @param {JXG.Image|JXG.Text} element A {@link JXG.Image} or {@link JXG.Text} object.
          * @param {Array} transformations An array of {@link JXG.Transformation} objects. This is usually the
          * transformations property of the given element <tt>el</tt>.
@@ -1930,13 +1986,16 @@ JXG.extend(
 
         /**
          * Highlights an object, i.e. changes the current colors of the object to its highlighting colors
-         * and highlighting stroke width.
+         * and highlighting strokewidth.
          * @param {JXG.GeometryElement} el Reference of the object that will be highlighted.
+         * @param {Boolean} [suppressHighlightStrokeWidth=undefined] If undefined or false, highlighting also changes strokeWidth. This might not be
+         * the cases for polygon borders. Thus, if a polygon is highlighted, its polygon borders change strokeWidth only if the polygon attribute
+         * highlightByStrokeWidth == true.
          * @returns {JXG.AbstractRenderer} Reference to the renderer
          * @see JXG.AbstractRenderer#updateTextStyle
          */
-        highlight: function (el) {
-            var i,
+        highlight: function (el, suppressHighlightStrokeWidth) {
+            var i, do_hl,
                 ev = el.visProp,
                 sw;
 
@@ -1944,6 +2003,11 @@ JXG.extend(
             if (!ev.draft) {
                 if (el.type === Const.OBJECT_TYPE_POLYGON) {
                     this.setObjectFillColor(el, ev.highlightfillcolor, ev.highlightfillopacity);
+                    do_hl = Type.evaluate(ev.highlightbystrokewidth);
+                    for (i = 0; i < el.borders.length; i++) {
+                        this.highlight(el.borders[i], !do_hl);
+                    }
+                    /*
                     for (i = 0; i < el.borders.length; i++) {
                         this.setObjectStrokeColor(
                             el.borders[i],
@@ -1951,6 +2015,7 @@ JXG.extend(
                             el.borders[i].visProp.highlightstrokeopacity
                         );
                     }
+                    */
                 } else {
                     if (el.elementClass === Const.OBJECT_CLASS_TEXT) {
                         this.updateTextStyle(el, true);
@@ -1974,7 +2039,12 @@ JXG.extend(
                         );
                     }
                 }
-                if (ev.highlightstrokewidth) {
+
+                // Highlight strokeWidth is suppressed if
+                // parameter suppressHighlightStrokeWidth is false or undefined.
+                // suppressHighlightStrokeWidth is false if polygon attribute
+                // highlightbystrokewidth is true.
+                if (ev.highlightstrokewidth && !suppressHighlightStrokeWidth) {
                     sw = Math.max(
                         Type.evaluate(ev.highlightstrokewidth),
                         Type.evaluate(ev.strokewidth)
@@ -2008,12 +2078,15 @@ JXG.extend(
                 if (el.type === Const.OBJECT_TYPE_POLYGON) {
                     this.setObjectFillColor(el, ev.fillcolor, ev.fillopacity);
                     for (i = 0; i < el.borders.length; i++) {
-                        this.setObjectStrokeColor(
-                            el.borders[i],
-                            el.borders[i].visProp.strokecolor,
-                            el.borders[i].visProp.strokeopacity
-                        );
+                        this.noHighlight(el.borders[i]);
                     }
+                    // for (i = 0; i < el.borders.length; i++) {
+                    //     this.setObjectStrokeColor(
+                    //         el.borders[i],
+                    //         el.borders[i].visProp.strokecolor,
+                    //         el.borders[i].visProp.strokeopacity
+                    //     );
+                    // }
                 } else {
                     if (el.elementClass === Const.OBJECT_CLASS_TEXT) {
                         this.updateTextStyle(el, false);
@@ -2062,19 +2135,19 @@ JXG.extend(
         },
 
         /**
-         * The tiny zoom bar shown on the bottom of a board (if showNavigation on board creation is true).
+         * The tiny zoom bar shown on the bottom of a board (if board attribute "showNavigation" is true).
          * It is a div element and gets the CSS class "JXG_navigation" and the id {board id}_navigationbar.
-         *
+         * <p>
          * The buttons get the CSS class "JXG_navigation_button" and the id {board_id}_name where name is
          * one of [top, down, left, right, out, 100, in, fullscreen, screenshot, reload, cleartraces].
-         *
-         * The symbols are hard-coded.
+         * <p>
+         * The symbols for zoom, navigation and reload are hard-coded.
          *
          * @param {JXG.Board} board Reference to a JSXGraph board.
          * @param {Object} attr Attributes of the navigation bar
-         *
+         * @private
          */
-        drawZoomBar: function (board, attr) {
+        drawNavigationBar: function (board, attr) {
             var doc,
                 node,
                 cancelbubble = function (e) {
@@ -2110,17 +2183,6 @@ JXG.extend(
                     button.setAttribute("id", id);
                     node.appendChild(button);
 
-                    // Highlighting is now done with CSS
-                    // Env.addEvent(button, 'mouseover', function () {
-                    //     this.style.backgroundColor = attr.highlightfillcolor;
-                    // }, button);
-                    // Env.addEvent(button, 'mouseover', function () {
-                    //     this.style.backgroundColor = attr.highlightfillcolor;
-                    // }, button);
-                    // Env.addEvent(button, 'mouseout', function () {
-                    //     this.style.backgroundColor = attr.fillcolor;
-                    // }, button);
-
                     Env.addEvent(
                         button,
                         "click",
@@ -2131,6 +2193,9 @@ JXG.extend(
                         board
                     );
                     // prevent the click from bubbling down to the board
+                    Env.addEvent(button, "pointerup", cancelbubble, board);
+                    Env.addEvent(button, "pointerdown", cancelbubble, board);
+                    Env.addEvent(button, "pointerleave", cancelbubble, board);
                     Env.addEvent(button, "mouseup", cancelbubble, board);
                     Env.addEvent(button, "mousedown", cancelbubble, board);
                     Env.addEvent(button, "touchend", cancelbubble, board);
@@ -2248,10 +2313,16 @@ JXG.extend(
          * @returns {Object} Reference to a JavaScript object. In case of SVG/VMLRenderer it's a reference to a SVG/VML node.
          */
         getElementById: function (id) {
+            var str;
             if (Type.exists(this.container)) {
                 // Use querySelector over getElementById for compatibility with both 'regular' document
                 // and ShadowDOM fragments.
-                return this.container.querySelector('#' + this.container.id + '_' + id);
+                str = this.container.id + '_' + id;
+                // Mask special symbols like '/' and '\' in id
+                if (Type.exists(CSS) && Type.exists(CSS.escape)) {
+                    str = CSS.escape(str);
+                }
+                return this.container.querySelector('#' + str);
             }
             return "";
         },
