@@ -76,27 +76,13 @@ JXG.CanvasRenderer = function (container, dim) {
         }
 
         this.container.innerHTML = [
-            '<canvas id="',
-            this.canvasId,
-            '" width="',
-            dim.width,
-            'px" height="',
-            dim.height,
-            'px"><',
-            "/canvas>"
+            '<canvas id="', this.canvasId, '" width="', dim.width, 'px" height="', dim.height, 'px"></canvas>'
         ].join("");
         this.canvasRoot = this.container.ownerDocument.getElementById(this.canvasId);
         this.canvasRoot.style.display = "block";
         this.context = this.canvasRoot.getContext("2d");
     } else if (Env.isNode()) {
-        // Do not use try to get more concise error message
         try {
-            // this.canvasId = typeof module === "object" ? module.require("canvas") : $__canvas;
-            // this.canvasRoot = new this.canvasId(500, 500);
-            // this.canvasId = (typeof module === 'object' ? module.require('canvas') : require('canvas'));
-
-            //this.canvasId = typeof module === "object" ? module.require('canvas') : import('canvas');
-            // this.canvasRoot = this.canvasId.createCanvas(500, 500);
             this.canvasRoot = JXG.createCanvas(500, 500);
             this.context = this.canvasRoot.getContext("2d");
         } catch (err) {
@@ -107,15 +93,6 @@ JXG.CanvasRenderer = function (container, dim) {
                 '    JXG.createCanvas = createCanvas;\n');
         }
     }
-
-    this.dashArray = [
-        [2, 2],
-        [5, 5],
-        [10, 10],
-        [20, 20],
-        [20, 10, 10, 10],
-        [20, 5, 10, 5]
-    ];
 };
 
 JXG.CanvasRenderer.prototype = new AbstractRenderer();
@@ -442,13 +419,19 @@ JXG.extend(
          */
         _stroke: function (el) {
             var context = this.context,
-                ev_dash = Type.evaluate(el.visProp.dash);
+                ev_dash = Type.evaluate(el.visProp.dash),
+                ds = Type.evaluate(el.visProp.dashscale),
+                sw = ds ? 0.5 * Type.evaluate(el.visProp.strokewidth) : 1;
 
             context.save();
 
             if (ev_dash > 0) {
                 if (context.setLineDash) {
-                    context.setLineDash(this.dashArray[ev_dash]);
+                    context.setLineDash(
+                        // sw could distinguish highlighting or not.
+                        // But it seems to preferable to ignore this.
+                        this.dashArray[ev_dash - 1].map(function (x) { return x * sw; })
+                    );
                 }
             } else {
                 this.context.lineDashArray = [];
@@ -594,6 +577,7 @@ JXG.extend(
                     this._stroke(el);
                     break;
                 case "triangleup":
+                case "A":
                 case "a":
                 case "^":
                     context.beginPath();
@@ -1321,14 +1305,33 @@ JXG.extend(
 
         // Already documented in JXG.AbstractRenderer
         transformImage: function (el, t) {
-            var m,
+            var m, s, cx, cy, node,
                 len = t.length,
                 ctx = this.context;
 
             if (len > 0) {
                 m = this.joinTransforms(el, t);
-                if (Math.abs(Numerics.det(m)) >= Mat.eps) {
-                    ctx.transform(m[1][1], m[2][1], m[1][2], m[2][2], m[1][0], m[2][0]);
+                if (el.elementClass === Const.OBJECT_CLASS_TEXT && el.visProp.display === 'html') {
+                    s = " matrix(" + [m[1][1], m[2][1], m[1][2], m[2][2], m[1][0], m[2][0]].join(",") + ") ";
+                    if (s.indexOf('NaN') === -1) {
+                        node = el.rendNode;
+                        node.style.transform = s;
+                        cx = -el.coords.scrCoords[1];
+                        cy = -el.coords.scrCoords[2];
+                        switch (Type.evaluate(el.visProp.anchorx)) {
+                            case 'right': cx += el.size[0]; break;
+                            case 'middle': cx += el.size[0] * 0.5; break;
+                        }
+                        switch (Type.evaluate(el.visProp.anchory)) {
+                            case 'bottom': cy += el.size[1]; break;
+                            case 'middle': cy += el.size[1] * 0.5; break;
+                        }
+                        node.style['transform-origin'] = (cx) + 'px ' + (cy) + 'px';
+                    }
+                } else {
+                    if (Math.abs(Numerics.det(m)) >= Mat.eps) {
+                        ctx.transform(m[1][1], m[2][1], m[1][2], m[2][2], m[1][0], m[2][0]);
+                    }
                 }
             }
         },
@@ -1690,7 +1693,7 @@ JXG.extend(
         },
 
         removeToInsertLater: function () {
-            return function () {};
+            return function () { };
         }
     }
 );
