@@ -133,7 +133,7 @@ JXG.SVGRenderer = function (container, dim) {
      * @returns DOM node to be added to this.defs.
      * @private
      */
-    this.createShadowFilter = function(id, rgb, opacity, blend, blur, offset) {
+    this.createShadowFilter = function (id, rgb, opacity, blend, blur, offset) {
         var filter = this.container.ownerDocument.createElementNS(this.svgNamespace, 'filter'),
             feOffset, feColor, feGaussianBlur, feBlend,
             mat;
@@ -162,9 +162,9 @@ JXG.SVGRenderer = function (container, dim) {
             rgb[1] /= 255;
             rgb[2] /= 255;
             mat = blend + ' 0 0 0 ' + rgb[0] +
-                      '  0 ' + blend + ' 0 0 ' + rgb[1] +
-                      '  0 0 ' + blend + ' 0 ' + rgb[2] +
-                      '  0 0 0 ' + opacity + ' 0';
+                '  0 ' + blend + ' 0 0 ' + rgb[1] +
+                '  0 0 ' + blend + ' 0 ' + rgb[2] +
+                '  0 0 0 ' + opacity + ' 0';
             feColor.setAttributeNS(null, 'values', mat);
         }
         filter.appendChild(feColor);
@@ -184,8 +184,49 @@ JXG.SVGRenderer = function (container, dim) {
         return filter;
     };
 
+    /**
+     * Create a "unique" string id from the arguments of the function.
+     * Concatenate all arguments by "_".
+     * "Unique" is achieved by simply prepending the container id.
+     * Do not escape the string.
+     *
+     * If the id is used in an "url()" call it must be eascaped.
+     *
+     * @params {String} one or strings which will be concatenated.
+     * @return {String}
+     * @private
+     */
+    this.uniqName = function () {
+        return this.container.id + '_' +
+            Array.prototype.slice.call(arguments).join('_');
+    };
+
+    /**
+     * Combine arguments to an URL string of the form
+     * url(#...)
+     * Masks the container id.
+     *
+     * @params {Objects} parts of the string
+     * @returns URL string
+     * @private
+     * @example
+     * this.toURL('aaa', '_', 'bbb', 'TriangleEnd')
+     * // Output:
+     * // url(#xxx_bbbTriangleEnd)
+     *
+     */
+    this.toURL = function () {
+        // ES6 would be [...arguments].join()
+        var str = Array.prototype.slice.call(arguments).join('');
+        // Mask special symbols like '/' and '\' in id
+        if (Type.exists(CSS) && Type.exists(CSS.escape)) {
+            str = CSS.escape(str);
+        }
+        return 'url(#' + str + ')';
+    };
+
     /* Default shadow filter */
-    this.defs.appendChild(this.createShadowFilter(this.container.id + '_' + 'f1', 'none', 1, 0.1, 3, [5, 5]));
+    this.defs.appendChild(this.createShadowFilter(this.uniqName('f1'), 'none', 1, 0.1, 3, [5, 5]));
 
     /**
      * JSXGraph uses a layer system to sort the elements on the board. This puts certain types of elements in front
@@ -209,26 +250,12 @@ JXG.SVGRenderer = function (container, dim) {
         this.foreignObjLayer.setAttribute("y", 0);
         this.foreignObjLayer.setAttribute("width", "100%");
         this.foreignObjLayer.setAttribute("height", "100%");
-        this.foreignObjLayer.setAttribute("id", this.container.id + "_foreignObj");
+        this.foreignObjLayer.setAttribute("id", this.uniqName('foreignObj'));
         this.svgRoot.appendChild(this.foreignObjLayer);
         this.supportsForeignObject = true;
     } catch (e) {
         this.supportsForeignObject = false;
     }
-
-    /**
-     * Defines dash patterns. Defined styles are: <ol>
-     * <li value="-1"> 2px dash, 2px space</li>
-     * <li> 5px dash, 5px space</li>
-     * <li> 10px dash, 10px space</li>
-     * <li> 20px dash, 20px space</li>
-     * <li> 20px dash, 10px space, 10px dash, 10px dash</li>
-     * <li> 20px dash, 5px space, 10px dash, 5px space</li></ol>
-     * @type Array
-     * @default ['2, 2', '5, 5', '10, 10', '20, 20', '20, 10, 10, 10', '20, 5, 10, 5']
-     * @see https://www.w3.org/TR/SVG2/painting.html#StrokeProperties
-     */
-    this.dashArray = ["2, 2", "5, 5", "10, 10", "20, 20", "20, 10, 10, 10", "20, 5, 10, 5"];
 };
 
 JXG.SVGRenderer.prototype = new AbstractRenderer();
@@ -281,7 +308,7 @@ JXG.extend(
                Defined by Bezier curves from mp_arrowheads.html
 
                In any case but type 3 the arrow head is 10 units long,
-               type 3 is 10 unitsb high.
+               type 3 is 10 units high.
                These 10 units are scaled to strokeWidth * arrowSize pixels, see
                this._setArrowWidth().
 
@@ -566,17 +593,12 @@ JXG.extend(
 
         // Already documented in JXG.AbstractRenderer
         displayCopyright: function (str, fontsize) {
-            var node = this.createPrim("text", "licenseText"),
+            var node = this.createPrim("text", 'licenseText'),
                 t;
-            node.setAttributeNS(null, "x", "20px");
-            node.setAttributeNS(null, "y", 2 + fontsize + "px");
-            node.setAttributeNS(
-                null,
-                "style",
-                "font-family:Arial,Helvetica,sans-serif; font-size:" +
-                    fontsize +
-                    "px; fill:#356AA0;  opacity:0.3;"
-            );
+            node.setAttributeNS(null, 'x', '20px');
+            node.setAttributeNS(null, 'y', 2 + fontsize + 'px');
+            node.setAttributeNS(null, 'style', 'font-family:Arial,Helvetica,sans-serif; font-size:' +
+                fontsize + 'px; fill:#356AA0;  opacity:0.3;');
             t = this.container.ownerDocument.createTextNode(str);
             node.appendChild(t);
             this.appendChildPrim(node, 0);
@@ -682,17 +704,35 @@ JXG.extend(
 
         // Already documented in JXG.AbstractRenderer
         transformImage: function (el, t) {
-            var s,
-                m,
+            var s, m,
                 node = el.rendNode,
                 str = "",
+                cx, cy,
                 len = t.length;
 
             if (len > 0) {
                 m = this.joinTransforms(el, t);
                 s = [m[1][1], m[2][1], m[1][2], m[2][2], m[1][0], m[2][0]].join(",");
-                str += " matrix(" + s + ") ";
-                node.setAttributeNS(null, "transform", str);
+                if (s.indexOf('NaN') === -1) {
+                    str += " matrix(" + s + ") ";
+                    if (el.elementClass === Const.OBJECT_CLASS_TEXT && el.visProp.display === 'html') {
+                        node.style.transform = str;
+                        cx = -el.coords.scrCoords[1];
+                        cy = -el.coords.scrCoords[2];
+                        switch (Type.evaluate(el.visProp.anchorx)) {
+                            case 'right': cx += el.size[0]; break;
+                            case 'middle': cx += el.size[0] * 0.5; break;
+                        }
+                        switch (Type.evaluate(el.visProp.anchory)) {
+                            case 'bottom': cy += el.size[1]; break;
+                            case 'middle': cy += el.size[1] * 0.5; break;
+                        }
+                        node.style['transform-origin'] = (cx) + 'px ' + (cy) + 'px';
+                    } else {
+                        // Images and texts with display:'internal'
+                        node.setAttributeNS(null, "transform", str);
+                    }
+                }
             }
         },
 
@@ -772,7 +812,7 @@ JXG.extend(
         // Already documented in JXG.AbstractRenderer
         createPrim: function (type, id) {
             var node = this.container.ownerDocument.createElementNS(this.svgNamespace, type);
-            node.setAttributeNS(null, "id", this.container.id + "_" + id);
+            node.setAttributeNS(null, "id", this.uniqName(id));
             node.style.position = "absolute";
             if (type === "path") {
                 node.setAttributeNS(null, "stroke-linecap", "round");
@@ -823,7 +863,8 @@ JXG.extend(
                     el.rendNode.setAttributeNS(
                         null,
                         "marker-start",
-                        "url(#" + this.container.id + "_" + el.id + "TriangleEnd)"
+                        // "url(#" + this.container.id + "_" + el.id + "TriangleEnd)"
+                        this.toURL(this.container.id, '_', el.id, 'TriangleEnd')
                     );
                 } else {
                     this.defs.appendChild(node2);
@@ -843,7 +884,8 @@ JXG.extend(
                     el.rendNode.setAttributeNS(
                         null,
                         "marker-end",
-                        "url(#" + this.container.id + "_" + el.id + "TriangleStart)"
+                        // "url(#" + this.container.id + "_" + el.id + "TriangleStart)"
+                        this.toURL(this.container.id, '_', el.id, 'TriangleStart')
                     );
                 } else {
                     this.defs.appendChild(node2);
@@ -1281,10 +1323,16 @@ JXG.extend(
         // documented in JXG.AbstractRenderer
         setDashStyle: function (el) {
             var dashStyle = Type.evaluate(el.visProp.dash),
+                ds = Type.evaluate(el.visProp.dashscale),
+                sw = ds ? 0.5 * Type.evaluate(el.visProp.strokewidth) : 1,
                 node = el.rendNode;
 
             if (dashStyle > 0) {
-                node.setAttributeNS(null, "stroke-dasharray", this.dashArray[dashStyle - 1]);
+                node.setAttributeNS(null, "stroke-dasharray",
+                    // sw could distinguish highlighting or not.
+                    // But it seems to preferable to ignore this.
+                    this.dashArray[dashStyle - 1].map(function (x) { return x * sw; }).join(',')
+                );
             } else {
                 if (node.hasAttributeNS(null, "stroke-dasharray")) {
                     node.removeAttributeNS(null, "stroke-dasharray");
@@ -1295,9 +1343,7 @@ JXG.extend(
         // documented in JXG.AbstractRenderer
         setGradient: function (el) {
             var fillNode = el.rendNode,
-                node,
-                node2,
-                node3,
+                node, node2, node3,
                 ev_g = Type.evaluate(el.visProp.gradient);
 
             if (ev_g === "linear" || ev_g === "radial") {
@@ -1309,8 +1355,9 @@ JXG.extend(
                 this.defs.appendChild(node);
                 fillNode.setAttributeNS(
                     null,
-                    "style",
-                    "fill:url(#" + this.container.id + "_" + el.id + "_gradient)"
+                    'style',
+                    // "fill:url(#" + this.container.id + "_" + el.id + "_gradient)"
+                    'fill:' + this.toURL(this.container.id + '_' + el.id + '_gradient')
                 );
                 el.gradNode1 = node2;
                 el.gradNode2 = node3;
@@ -1401,9 +1448,9 @@ JXG.extend(
                 null,
                 "style",
                 "stop-color:" +
-                    Type.evaluate(el.visProp.gradientsecondcolor) +
-                    ";stop-opacity:" +
-                    Type.evaluate(el.visProp.gradientsecondopacity)
+                Type.evaluate(el.visProp.gradientsecondcolor) +
+                ";stop-opacity:" +
+                Type.evaluate(el.visProp.gradientsecondopacity)
             );
             node2.setAttributeNS(
                 null,
@@ -1435,7 +1482,8 @@ JXG.extend(
             var node, props,
                 transitionArr = [],
                 transitionStr,
-                i, len,
+                i,
+                len = 0,
                 nodes = ["rendNode", "rendNodeTriangleStart", "rendNodeTriangleEnd"];
 
             if (duration === undefined) {
@@ -1468,9 +1516,11 @@ JXG.extend(
             //         " ry " + duration + "ms";
             // }
 
-            len = props.length;
+            if (Type.exists(props)) {
+                len = props.length;
+            }
             for (i = 0; i < len; i++) {
-                transitionArr.push(props[i] + ' ' + duration+ 'ms');
+                transitionArr.push(props[i] + ' ' + duration + 'ms');
             }
             transitionStr = transitionArr.join(', ');
 
@@ -1637,9 +1687,7 @@ JXG.extend(
                     if (Type.evaluate(el.visProp.firstarrow)) {
                         this._setArrowColor(
                             el.rendNodeTriangleStart,
-                            c,
-                            oo,
-                            el,
+                            c, oo, el,
                             el.visPropCalc.typeFirst
                         );
                     }
@@ -1647,9 +1695,7 @@ JXG.extend(
                     if (Type.evaluate(el.visProp.lastarrow)) {
                         this._setArrowColor(
                             el.rendNodeTriangleEnd,
-                            c,
-                            oo,
-                            el,
+                            c, oo, el,
                             el.visPropCalc.typeLast
                         );
                     }
@@ -1742,7 +1788,8 @@ JXG.extend(
             if (Type.exists(el.rendNode)) {
                 if (show) {
                     if (use_board_filter) {
-                        el.rendNode.setAttributeNS(null, 'filter', 'url(#' + this.container.id + '_' + 'f1)');
+                        el.rendNode.setAttributeNS(null, 'filter', this.toURL(this.container.id + '_' + 'f1'))
+                        // 'url(#' + this.container.id + '_' + 'f1)');
                     } else {
                         node = this.container.ownerDocument.getElementById(id);
                         if (node) {
@@ -1750,7 +1797,8 @@ JXG.extend(
                         }
                         id = el.rendNode.id + '_' + 'f1';
                         this.defs.appendChild(this.createShadowFilter(id, c, op, bl, b, o));
-                        el.rendNode.setAttributeNS(null, 'filter', 'url(#' + id + ')');
+                        el.rendNode.setAttributeNS(null, 'filter', this.toURL(id));
+                        // 'url(#' + id + ')');
                     }
                 } else {
                     el.rendNode.removeAttributeNS(null, 'filter');
@@ -1852,24 +1900,24 @@ JXG.extend(
                     null,
                     "d",
                     "M " +
-                        (x - d) +
-                        " " +
-                        y +
-                        " " +
-                        "L " +
-                        (x + d) +
-                        " " +
-                        y +
-                        " " +
-                        "M " +
-                        x +
-                        " " +
-                        (y - d) +
-                        " " +
-                        "L " +
-                        x +
-                        " " +
-                        (y + d)
+                    (x - d) +
+                    " " +
+                    y +
+                    " " +
+                    "L " +
+                    (x + d) +
+                    " " +
+                    y +
+                    " " +
+                    "M " +
+                    x +
+                    " " +
+                    (y - d) +
+                    " " +
+                    "L " +
+                    x +
+                    " " +
+                    (y + d)
                 );
                 this.updateEllipsePrim(this.touchpoints[2 * i + 1], pos[0], pos[1], 25, 25);
             }
@@ -1947,22 +1995,54 @@ JXG.extend(
         },
 
         /**
-         * Return a data URI of the SVG code representeing the construction.
+         * Return a data URI of the SVG code representing the construction.
          * The SVG code of the construction is base64 encoded. The return string starts
          * with "data:image/svg+xml;base64,...".
          *
          * @param {Boolean} ignoreTexts If true, the foreignObject tag is set to display=none.
          * This is necessary for older versions of Safari. Default: false
          * @returns {String}  data URI string
+         *
+         * @example
+         * var A = board.create('point', [2, 2]);
+         *
+         * var txt = board.renderer.dumpToDataURI(false);
+         * // txt consists of a string of the form
+         * // data:image/svg+xml;base64,PHN2Zy. base64 encoded SVG..+PC9zdmc+
+         * // Behind the comma, there is the base64 encoded SVG code
+         * // which is decoded with atob().
+         * // The call of decodeURIComponent(escape(...)) is necessary
+         * // to handle unicode strings correctly.
+         * var ar = txt.split(',');
+         * document.getElementById('output').value = decodeURIComponent(escape(atob(ar[1])));
+         *
+         * </pre><div id="JXG1bad4bec-6d08-4ce0-9b7f-d817e8dd762d" class="jxgbox" style="width: 300px; height: 300px;"></div>
+         * <textarea id="output2023" rows="5" cols="50"></textarea>
+         * <script type="text/javascript">
+         *     (function() {
+         *         var board = JXG.JSXGraph.initBoard('JXG1bad4bec-6d08-4ce0-9b7f-d817e8dd762d',
+         *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+         *     var A = board.create('point', [2, 2]);
+         *
+         *     var txt = board.renderer.dumpToDataURI(false);
+         *     // txt consists of a string of the form
+         *     // data:image/svg+xml;base64,PHN2Zy. base64 encoded SVG..+PC9zdmc+
+         *     // Behind the comma, there is the base64 encoded SVG code
+         *     // which is decoded with atob().
+         *     // The call of decodeURIComponent(escape(...)) is necessary
+         *     // to handle unicode strings correctly.
+         *     var ar = txt.split(',');
+         *     document.getElementById('output2023').value = decodeURIComponent(escape(atob(ar[1])));
+         *
+         *     })();
+         *
+         * </script><pre>
+         *
          */
         dumpToDataURI: function (ignoreTexts) {
             var svgRoot = this.svgRoot,
                 btoa = window.btoa || Base64.encode,
-                svg,
-                virtualNode,
-                doc,
-                i,
-                len,
+                svg, i, len,
                 values = [];
 
             // Move all HTML tags (beside the SVG root) of the container
@@ -1973,12 +2053,11 @@ JXG.extend(
             if (this.container.hasChildNodes() && Type.exists(this.foreignObjLayer)) {
                 if (!ignoreTexts) {
                     this.foreignObjLayer.setAttribute("display", "inline");
-                }
-                while (svgRoot.nextSibling) {
-                    // Copy all value attributes
-                    values = values.concat(this._getValuesOfDOMElements(svgRoot.nextSibling));
-
-                    this.foreignObjLayer.appendChild(svgRoot.nextSibling);
+                    while (svgRoot.nextSibling) {
+                        // Copy all value attributes
+                        values = values.concat(this._getValuesOfDOMElements(svgRoot.nextSibling));
+                        this.foreignObjLayer.appendChild(svgRoot.nextSibling);
+                    }
                 }
             }
 
@@ -2013,6 +2092,7 @@ JXG.extend(
             // Safari fails if the svg string contains a "&nbsp;"
             // Obsolete with Safari 12+
             svg = svg.replace(/&nbsp;/g, " ");
+            svg = svg.replace(/url\(&quot;(.*)&quot;\)/g, "url($1)");
 
             // Move all HTML tags back from
             // the foreignObject element to the container
@@ -2031,6 +2111,9 @@ JXG.extend(
          * Convert the SVG construction into an HTML canvas image.
          * This works for all SVG supporting browsers. Implemented as Promise.
          * <p>
+         * Might fail if any text element or foreign object element contains SVG. This
+         * is the case e.g. for the default fullscreen symbol.
+         * <p>
          * For IE, it is realized as function.
          * It works from version 9, with the exception that HTML texts
          * are ignored on IE. The drawing is done with a delay of
@@ -2052,10 +2135,8 @@ JXG.extend(
          * 	setTimeout(function() { console.log('done'); }, 400);
          */
         dumpToCanvas: function (canvasId, w, h, ignoreTexts) {
-            var svg,
-                tmpImg,
-                cv,
-                ctx,
+            var svg, tmpImg,
+                cv, ctx,
                 doc = this.container.ownerDocument;
 
             // Prepare the canvas element
@@ -2119,7 +2200,7 @@ JXG.extend(
          * <ul>
          * <li> IE: No
          * <li> Edge: full
-         * <li>Firefox: full
+         * <li> Firefox: full
          * <li> Chrome: full
          * <li> Safari: full (No text support in versions prior to 12).
          * </ul>
@@ -2136,18 +2217,13 @@ JXG.extend(
             var node,
                 doc = this.container.ownerDocument,
                 parent = this.container.parentNode,
-                cPos,
-                canvas,
-                id,
-                img,
-                button,
-                buttonText,
-                w,
-                h,
+                // cPos,
+                // cssTxt,
+                canvas, id, img,
+                button, buttonText,
+                w, h,
                 bas = board.attr.screenshot,
-                zbar,
-                zbarDisplay,
-                cssTxt,
+                navbar, navbarDisplay, insert,
                 newImg = false,
                 _copyCanvasToImg,
                 isDebug = false;
@@ -2220,11 +2296,11 @@ JXG.extend(
             }
 
             // Hide navigation bar in board
-            // zbar = document.getElementById(this.container.id + '_navigationbar');
-            zbar = doc.getElementById(this.container.id + "_navigationbar");
-            if (Type.exists(zbar)) {
-                zbarDisplay = zbar.style.display;
-                zbar.style.display = "none";
+            navbar = doc.getElementById(this.uniqName('navigationbar'));
+            if (Type.exists(navbar)) {
+                navbarDisplay = navbar.style.display;
+                navbar.style.display = "none";
+                insert = this.removeToInsertLater(navbar);
             }
 
             _copyCanvasToImg = function () {
@@ -2246,9 +2322,10 @@ JXG.extend(
                 window.setTimeout(_copyCanvasToImg, 200);
             }
 
-            // Show navigation bar in board
-            if (Type.exists(zbar)) {
-                zbar.style.display = zbarDisplay;
+            // Reinsert navigation bar in board
+            if (Type.exists(navbar)) {
+                navbar.style.display = navbarDisplay;
+                insert();
             }
 
             return this;
