@@ -402,10 +402,8 @@ JXG.extend(
                     return { width: element.clientWidth, height: element.clientHeight };
                 }
 
-                // a parent might be set to display:none; try reading them from styles
-                style = window.getComputedStyle
-                    ? window.getComputedStyle(element)
-                    : element.style;
+                // A parent might be set to display:none; try reading them from styles
+                style = window.getComputedStyle ? window.getComputedStyle(element) : element.style;
                 return {
                     width: pixelDimRegExp.test(style.width) ? parseFloat(style.width) : 0,
                     height: pixelDimRegExp.test(style.height) ? parseFloat(style.height) : 0
@@ -547,7 +545,9 @@ JXG.extend(
         },
 
         /**
-         * Cross browser mouse / touch coordinates retrieval relative to the board's top left corner.
+         * Cross browser mouse / pointer / touch coordinates retrieval relative to the documents's top left corner.
+         * This method might be a bit outdated today, since pointer events and clientX/Y are omnipresent.
+         * 
          * @param {Object} [e] The browsers event object. If omitted, <tt>window.event</tt> will be used.
          * @param {Number} [index] If <tt>e</tt> is a touch event, this provides the index of the touch coordinates, i.e. it determines which finger.
          * @param {Object} [doc] The document object.
@@ -998,6 +998,7 @@ JXG.extend(
                 );
             }
         }
+
     }
 );
 
